<?php
/**
 * Shapes Settings
 * Display the shapes settings meta box.
 *
 * @author      Aisconverse
 * @category    Admin
 * @package     Treweler/Admin/Meta Boxes
 * @version     1.10
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

if ( class_exists( 'TWER_Meta_Box_Shape_Settings', false ) ) {
  return;
}

if ( ! class_exists( 'TWER_Meta_Boxes', false ) ) {
  include_once 'abstract-class-twer-meta-boxes.php';
}

/**
 * TWER_Meta_Box_Shape_Settings Class.
 */
class TWER_Meta_Box_Shape_Settings extends TWER_Meta_Boxes {

  protected function set_tabs() {
  }

  protected function get_maps() {
    global $post;
    $tmp_post = $post;
    $post_id = isset( $post->ID ) ? $post->ID : '';

    $setMap = get_post_meta( $post_id, '_treweler_map_id', true );

    $maps_posts = get_posts( [
      'post_type'      => 'map',
      'post_status'    => 'publish',
      'posts_per_page' => - 1,
      'orderby'        => 'title',
      'order'          => 'ASC'
    ] );
    $maps = [];
    if ( ! empty( $maps_posts ) ) {
      foreach ( $maps_posts as $post ) {
        setup_postdata( $post );
        $postId = get_the_ID();
        $post_title = get_the_title();
        $map_style = trim( get_post_meta( $postId, '_treweler_map_custom_style',
          true ) ) != "" ? get_post_meta( $postId, '_treweler_map_custom_style',
          true ) : get_post_meta( $postId, '_treweler_map_styles', true );

        $maps[ $postId ] = $post_title;
      }
      wp_reset_postdata();
    }


    $post = $tmp_post;

    if ( is_array( $setMap ) && ! empty( $setMap ) ) {
      $maps_sorted = [];
      foreach ( $setMap as $mapKey ) {
        if ( 'publish' !== get_post_status( $mapKey ) ) {
          continue;
        }

        $maps_sorted[ $mapKey ] = $maps[ $mapKey ];
        unset( $maps[ $mapKey ] );
      }
      $maps = $maps_sorted + $maps;
    }

    return $maps;
  }

  protected function set_fields() {

    $this->fields = [
      [
        'type'        => 'select',
        'name'        => 'map_id',
        'class'       => [ 'js-map-multiselect' ],
        'atts'        => [ 'multiple' ],
        'group_class' => 'form-group col',
        'label'       => esc_html__( 'Shape Maps', 'treweler' ),
        'options'     => $this->get_maps(),
        'selected'    => ''
      ],
    ];
  }

}
