<?php
/**
 * Map details meta box.
 *
 * @package Treweler/Admin
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

$post_id = isset( $post->ID ) ? $post->ID : '';
$prefix = '_treweler_';
$meta_data = twer_get_data( $post_id );
$post_meta_old = get_post_meta( $post_id );

$name = get_post_meta( $post_id, '_treweler_map_details_name', true );
$name_color = get_post_meta( $post_id, '_treweler_map_details_name_color', true );
$name_color = $name_color != '' ? $name_color : '#000';
$desc = get_post_meta( $post_id, '_treweler_map_details_description', true );
$desc_color = get_post_meta( $post_id, '_treweler_map_details_description_color', true );
$desc_color = $desc_color != '' ? $desc_color : '#000';
$position = get_post_meta( $post_id, '_treweler_map_details_position', true );
$projection = get_post_meta( $post_id, '_treweler_map_projection', true );
$custom_color = get_option( 'treweler_mapbox_colorpicker_custom_color' );
$defaultColors = '#F44336|#EC407A|#E046C6|#B94AEF|#8559FF|#317DFC|#426D7E|#027F71|#008A43|#238C28|#4B7715|#756B11|#C06018|#9B5A45|#505050|#00B0F6|#00C5AF|#00BC5B|#18AF1F|#5DA900|#A19100|#FF7814|#FF5D28|#FFFFFF|#000000|';
$logoSize = get_post_meta( $post_id, '_treweler_map_details_logo_size', true );

$fields_attribution = [
  [
    'type'  => 'select',
    'name'  => $prefix . 'wordmark_position',
    'label' => esc_html__( 'Wordmark position', 'treweler' ),
    'id'    => 'twer-wordmark-position',
    'value' => [
      'top-left'     => [
        'title'    => esc_html__( 'Top Left', 'treweler' ),
        'selected' => in_array( 'top-left',
          isset( $meta_data->wordmark_position ) ? (array) $meta_data->wordmark_position : [] )
      ],
      'top-right'    => [
        'title'    => esc_html__( 'Top Right', 'treweler' ),
        'selected' => in_array( 'top-right',
          isset( $meta_data->wordmark_position ) ? (array) $meta_data->wordmark_position : [] )
      ],
      'bottom-left'  => [
        'title'    => esc_html__( 'Bottom Left', 'treweler' ),
        'selected' => in_array( 'bottom-left',
          isset( $meta_data->wordmark_position ) ? (array) $meta_data->wordmark_position : [ 'bottom-left' ] )
      ],
      'bottom-right' => [
        'title'    => esc_html__( 'Bottom Right', 'treweler' ),
        'selected' => in_array( 'bottom-right',
          isset( $meta_data->wordmark_position ) ? (array) $meta_data->wordmark_position : [] )
      ]
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'attribution_position',
    'label' => esc_html__( 'Attribution position', 'treweler' ),
    'id'    => 'twer-attribution-position',
    'value' => [
      'top-left'     => [
        'title'    => esc_html__( 'Top Left', 'treweler' ),
        'selected' => in_array( 'top-left',
          isset( $meta_data->attribution_position ) ? (array) $meta_data->attribution_position : [] )
      ],
      'top-right'    => [
        'title'    => esc_html__( 'Top Right', 'treweler' ),
        'selected' => in_array( 'top-right',
          isset( $meta_data->attribution_position ) ? (array) $meta_data->attribution_position : [] )
      ],
      'bottom-left'  => [
        'title'    => esc_html__( 'Bottom Left', 'treweler' ),
        'selected' => in_array( 'bottom-left',
          isset( $meta_data->attribution_position ) ? (array) $meta_data->attribution_position : [] )
      ],
      'bottom-right' => [
        'title'    => esc_html__( 'Bottom Right', 'treweler' ),
        'selected' => in_array( 'bottom-right',
          isset( $meta_data->attribution_position ) ? (array) $meta_data->attribution_position : [ 'bottom-right' ] )
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'compact_attribution',
    'id'    => 'twer-compact-attribution',
    'label' => esc_html__( 'Compact attribution', 'treweler' ),
    'value' => [
      'compact_attribution' => [
        'title'   => '',
        'checked' => in_array( 'compact_attribution',
          isset( $meta_data->compact_attribution ) ? (array) $meta_data->compact_attribution : [] )
      ]
    ]
  ]
];

$fields_clusters = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'map_enable_clustering',
    'label' => esc_html__( 'Enable Clustering', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'map_enable_clustering',
          isset( $meta_data->map_enable_clustering ) ? (array) $meta_data->map_enable_clustering : [ 'map_enable_clustering' ] ),
        'value'   => 'map_enable_clustering'
      ]
    ]
  ],
  [
    'type'  => 'colorpicker',
    'name'  => $prefix . 'map_cluster_color',
    'id'    => 'twer-map-cluster-color',
    'label' => esc_html__( 'Cluster Color', 'treweler' ),
    'value' => isset( $meta_data->map_cluster_color ) ? $meta_data->map_cluster_color : '#4b7715'
  ],
  [
    'type'        => 'text',
    'name'        => $prefix . 'map_cluster_max_zoom',
    'size'        => 'small',
    'label'       => esc_html__( 'Clustering Max Zoom', 'treweler' ),
    'value'       => isset( $meta_data->map_cluster_max_zoom ) ? $meta_data->map_cluster_max_zoom : '',
    'placeholder' => '14'
  ],
];

$fields_controls = [
  [
    'type'  => 'group',
    'name'  => $prefix . 'map_controls',
    'label' => esc_html__( 'Distance Scale', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'distance_scale',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'distance_scale',
              isset( $meta_data->map_controls['distance_scale'] ) ? (array) $meta_data->map_controls['distance_scale'] : [] ),
            'value'   => 'distance_scale'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'distance_position',
        'value' => [
          [
            'label'    => esc_html__( 'Top Left', 'treweler' ),
            'selected' => in_array( 'top-left',
              isset( $meta_data->map_controls['distance_position'] ) ? (array) $meta_data->map_controls['distance_position'] : [] ),
            'value'    => 'top-left'
          ],
          [
            'label'    => esc_html__( 'Top Right', 'treweler' ),
            'selected' => in_array( 'top-right',
              isset( $meta_data->map_controls['distance_position'] ) ? (array) $meta_data->map_controls['distance_position'] : [] ),
            'value'    => 'top-right'
          ],
          [
            'label'    => esc_html__( 'Bottom Left', 'treweler' ),
            'selected' => in_array( 'bottom-left',
              isset( $meta_data->map_controls['distance_position'] ) ? (array) $meta_data->map_controls['distance_position'] : [] ),
            'value'    => 'bottom-left'
          ],
          [
            'label'    => esc_html__( 'Bottom Right', 'treweler' ),
            'selected' => in_array( 'bottom-right',
              isset( $meta_data->map_controls['distance_position'] ) ? (array) $meta_data->map_controls['distance_position'] : [ 'bottom-right' ] ),
            'value'    => 'bottom-right'
          ],
        ]
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'map_controls',
    'label' => esc_html__( 'Fullscreen', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'fullscreen',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'fullscreen',
              isset( $meta_data->map_controls['fullscreen'] ) ? (array) $meta_data->map_controls['fullscreen'] : [] ),
            'value'   => 'fullscreen'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'fullscreen_position',
        'value' => [
          [
            'label'    => esc_html__( 'Top Left', 'treweler' ),
            'selected' => in_array( 'top-left',
              isset( $meta_data->map_controls['fullscreen_position'] ) ? (array) $meta_data->map_controls['fullscreen_position'] : [] ),
            'value'    => 'top-left'
          ],
          [
            'label'    => esc_html__( 'Top Right', 'treweler' ),
            'selected' => in_array( 'top-right',
              isset( $meta_data->map_controls['fullscreen_position'] ) ? (array) $meta_data->map_controls['fullscreen_position'] : [ 'top-right' ] ),
            'value'    => 'top-right'
          ],
          [
            'label'    => esc_html__( 'Bottom Left', 'treweler' ),
            'selected' => in_array( 'bottom-left',
              isset( $meta_data->map_controls['fullscreen_position'] ) ? (array) $meta_data->map_controls['fullscreen_position'] : [] ),
            'value'    => 'bottom-left'
          ],
          [
            'label'    => esc_html__( 'Bottom Right', 'treweler' ),
            'selected' => in_array( 'bottom-right',
              isset( $meta_data->map_controls['fullscreen_position'] ) ? (array) $meta_data->map_controls['fullscreen_position'] : [] ),
            'value'    => 'bottom-right'
          ],
        ]
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'map_controls',
    'label' => esc_html__( 'Search', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'search',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'search',
              isset( $meta_data->map_controls['search'] ) ? (array) $meta_data->map_controls['search'] : [] ),
            'value'   => 'search'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'search_position',
        'value' => [
          [
            'label'    => esc_html__( 'Top Left', 'treweler' ),
            'selected' => in_array( 'top-left',
              isset( $meta_data->map_controls['search_position'] ) ? (array) $meta_data->map_controls['search_position'] : [ 'top-left' ] ),
            'value'    => 'top-left'
          ],
          [
            'label'    => esc_html__( 'Top Right', 'treweler' ),
            'selected' => in_array( 'top-right',
              isset( $meta_data->map_controls['search_position'] ) ? (array) $meta_data->map_controls['search_position'] : [] ),
            'value'    => 'top-right'
          ],
          [
            'label'    => esc_html__( 'Bottom Left', 'treweler' ),
            'selected' => in_array( 'bottom-left',
              isset( $meta_data->map_controls['search_position'] ) ? (array) $meta_data->map_controls['search_position'] : [] ),
            'value'    => 'bottom-left'
          ],
          [
            'label'    => esc_html__( 'Bottom Right', 'treweler' ),
            'selected' => in_array( 'bottom-right',
              isset( $meta_data->map_controls['search_position'] ) ? (array) $meta_data->map_controls['search_position'] : [] ),
            'value'    => 'bottom-right'
          ],
        ]
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'map_controls',
    'label' => esc_html__( 'Zoom & Pan', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'zoom_pan',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'zoom_pan',
              isset( $meta_data->map_controls['zoom_pan'] ) ? (array) $meta_data->map_controls['zoom_pan'] : [] ),
            'value'   => 'zoom_pan'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'zoom_pan_position',
        'value' => [
          [
            'label'    => esc_html__( 'Top Left', 'treweler' ),
            'selected' => in_array( 'top-left',
              isset( $meta_data->map_controls['zoom_pan_position'] ) ? (array) $meta_data->map_controls['zoom_pan_position'] : [] ),
            'value'    => 'top-left'
          ],
          [
            'label'    => esc_html__( 'Top Right', 'treweler' ),
            'selected' => in_array( 'top-right',
              isset( $meta_data->map_controls['zoom_pan_position'] ) ? (array) $meta_data->map_controls['zoom_pan_position'] : [ 'top-right' ] ),
            'value'    => 'top-right'
          ],
          [
            'label'    => esc_html__( 'Bottom Left', 'treweler' ),
            'selected' => in_array( 'bottom-left',
              isset( $meta_data->map_controls['zoom_pan_position'] ) ? (array) $meta_data->map_controls['zoom_pan_position'] : [] ),
            'value'    => 'bottom-left'
          ],
          [
            'label'    => esc_html__( 'Bottom Right', 'treweler' ),
            'selected' => in_array( 'bottom-right',
              isset( $meta_data->map_controls['zoom_pan_position'] ) ? (array) $meta_data->map_controls['zoom_pan_position'] : [] ),
            'value'    => 'bottom-right'
          ],
        ]
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'map_controls',
    'label' => esc_html__( 'Geolocate', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'geolocate',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'geolocate',
              isset( $meta_data->map_controls['geolocate'] ) ? (array) $meta_data->map_controls['geolocate'] : [] ),
            'value'   => 'geolocate'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'geolocate_position',
        'value' => [
          [
            'label'    => esc_html__( 'Top Left', 'treweler' ),
            'selected' => in_array( 'top-left',
              isset( $meta_data->map_controls['geolocate_position'] ) ? (array) $meta_data->map_controls['geolocate_position'] : [] ),
            'value'    => 'top-left'
          ],
          [
            'label'    => esc_html__( 'Top Right', 'treweler' ),
            'selected' => in_array( 'top-right',
              isset( $meta_data->map_controls['geolocate_position'] ) ? (array) $meta_data->map_controls['geolocate_position'] : [ 'top-right' ] ),
            'value'    => 'top-right'
          ],
          [
            'label'    => esc_html__( 'Bottom Left', 'treweler' ),
            'selected' => in_array( 'bottom-left',
              isset( $meta_data->map_controls['geolocate_position'] ) ? (array) $meta_data->map_controls['geolocate_position'] : [] ),
            'value'    => 'bottom-left'
          ],
          [
            'label'    => esc_html__( 'Bottom Right', 'treweler' ),
            'selected' => in_array( 'bottom-right',
              isset( $meta_data->map_controls['geolocate_position'] ) ? (array) $meta_data->map_controls['geolocate_position'] : [] ),
            'value'    => 'bottom-right'
          ],
        ]
      ],
    ]
  ],
];

$fields_widgets = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'widgets_show',
    'label' => esc_html__( 'Show Widgets', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'widgets_show',
          isset( $meta_data->widgets_show ) ? (array) $meta_data->widgets_show : [] ),
        'value'   => 'widgets_show'
      ]
    ]
  ],
  [
    'type'  => 'widgets',
    'name'  => $prefix . 'widgets',
    'label' => esc_html__( 'Widgets', 'treweler' ),
    'value' => [
      [
        [
          'type'  => 'widget',
          'name'  => 'top_left',
          'label' => esc_html__( 'Top Left', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),
              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ],
        [
          'type'  => 'widget',
          'name'  => 'middle_left',
          'label' => esc_html__( 'Middle Left', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),

              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ],
        [
          'type'  => 'widget',
          'name'  => 'bottom_left',
          'label' => esc_html__( 'Bottom Left', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),
              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ],
      ],
      [
        [
          'type'  => 'widget',
          'name'  => 'top_right',
          'label' => esc_html__( 'Top Right', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),
              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ],
        [
          'type'  => 'widget',
          'name'  => 'middle_right',
          'label' => esc_html__( 'Middle Right', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),
              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ],
        [
          'type'  => 'widget',
          'name'  => 'bottom_right',
          'label' => esc_html__( 'Bottom Right', 'treweler' ),
          'value' => [
            [
              'type'  => 'text',
              'name'  => 'value',
              'label' => esc_html__( 'Value', 'treweler' ),
              'value' => ''
            ],
            [
              'type'  => 'text',
              'name'  => 'description',
              'label' => esc_html__( 'Description', 'treweler' ),
              'value' => ''
            ]
          ]
        ]
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'widgets_bg',
    'label' => esc_html__( 'Show Background', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'widgets_bg',
          isset( $meta_data->widgets_bg ) ? (array) $meta_data->widgets_bg : ['widgets_bg'] ),
        'value'   => 'widgets_bg'
      ]
    ]
  ],
  [
    'type'  => 'colorpicker',
    'name'  => $prefix . 'widgets_color',
    'label' => esc_html__( 'Color', 'treweler' ),
    'value' => isset( $meta_data->widgets_color ) ? $meta_data->widgets_color : '#000'
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'widgets_font_weight',
    'label' => esc_html__( 'Font Weight', 'treweler' ),
    'value' => [
      [
        'label'    => esc_html__( 'Thin 100', 'treweler' ),
        'selected' => in_array( '100',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '100'
      ],
      [
        'label'    => esc_html__( 'Extra Light 200', 'treweler' ),
        'selected' => in_array( '200',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '200'
      ],
      [
        'label'    => esc_html__( 'Light 300', 'treweler' ),
        'selected' => in_array( '300',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '300'
      ],
      [
        'label'    => esc_html__( 'Regular 400', 'treweler' ),
        'selected' => in_array( '400',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [ '400'] ),
        'value'    => '400'
      ],
      [
        'label'    => esc_html__( 'Medium 500', 'treweler' ),
        'selected' => in_array( '500',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '500'
      ],
      [
        'label'    => esc_html__( 'Semi Bold 600', 'treweler' ),
        'selected' => in_array( '600',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '600'
      ],
      [
        'label'    => esc_html__( 'Bold 700', 'treweler' ),
        'selected' => in_array( '700',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [ ] ),
        'value'    => '700'
      ],
      [
        'label'    => esc_html__( 'Extra Bold 800', 'treweler' ),
        'selected' => in_array( '800',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '800'
      ],
      [
        'label'    => esc_html__( 'Black 900', 'treweler' ),
        'selected' => in_array( '900',
          isset( $meta_data->widgets_font_weight ) ? (array) $meta_data->widgets_font_weight : [] ),
        'value'    => '900'
      ],
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'widgets_gradient',
    'label' => esc_html__( 'Show Gradient', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'widgets_gradient',
          isset( $meta_data->widgets_gradient ) ? (array) $meta_data->widgets_gradient : [] ),
        'value'   => 'widgets_gradient'
      ]
    ]
  ],
  [
    'type'  => 'colorpicker',
    'name'  => $prefix . 'widgets_gradient_color',
    'label' => esc_html__( 'Gradient Color', 'treweler' ),
    'value' => isset( $meta_data->widgets_gradient_color ) ? $meta_data->widgets_gradient_color : '#ffffff'
  ],
  [
    'type'  => 'range',
    'name'  => $prefix . 'widgets_gradient_opacity',
    'label' => esc_html__( 'Gradient Opacity', 'treweler' ),
    'value' => [
      'current' => isset( $meta_data->widgets_gradient_opacity ) ? $meta_data->widgets_gradient_opacity : '1',
      'min'     => '0',
      'max'     => '1',
      'step'    => '0.01'
    ],
    'help'  => esc_html__( 'The opacity property can take a value from 0.0 - 1.0. The lower value, the more transparent.',
      'treweler' )
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'widgets_gradient_position',
    'label' => esc_html__( 'Gradient Position', 'treweler' ),
    'value' => [
      [
        'label'    => esc_html__( 'Left', 'treweler' ),
        'selected' => in_array( 'left',
          isset( $meta_data->widgets_gradient_position ) ? (array) $meta_data->widgets_gradient_position : [ 'left' ] ),
        'value'    => 'left'
      ],
      [
        'label'    => esc_html__( 'Right', 'treweler' ),
        'selected' => in_array( 'right',
          isset( $meta_data->widgets_gradient_position ) ? (array) $meta_data->widgets_gradient_position : [] ),
        'value'    => 'right'
      ],
      [
        'label'    => esc_html__( 'Left and Right', 'treweler' ),
        'selected' => in_array( 'left-right',
          isset( $meta_data->widgets_gradient_position ) ? (array) $meta_data->widgets_gradient_position : [] ),
        'value'    => 'left-right'
      ]
    ]
  ]
];

$fields_camera = [
  [
    'type'  => 'range',
    'name'  => $prefix . 'camera_initial_bearing',
    'label' => esc_html__( 'Initial Bearing', 'treweler' ),
    'value' => [
      'current' => isset( $meta_data->camera_initial_bearing ) ? $meta_data->camera_initial_bearing : '0',
      'min'     => '-360',
      'max'     => '360',
      'step'    => '0.01'
    ],
    'help'  => esc_html__( "The map's angle of rotation, measured in degrees counter-clockwise from north.",
      'treweler' )
  ],
  [
    'type'  => 'range',
    'name'  => $prefix . 'camera_initial_pitch',
    'label' => esc_html__( 'Initial Pitch', 'treweler' ),
    'value' => [
      'current' => isset( $meta_data->camera_initial_pitch ) ? $meta_data->camera_initial_pitch : '0',
      'min'     => '0',
      'max'     => '85',
      'step'    => '0.01'
    ],
    'help'  => esc_html__( "The map's angle towards the horizon measured in degrees.",
      'treweler' )
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'camera_bearing',
    'label' => esc_html__( 'Allow Pitch & Bearing', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'camera_bearing',
          isset( $meta_data->camera_bearing ) ? (array) $meta_data->camera_bearing : [] ),
        'value'   => 'camera_bearing'
      ]
    ]
  ],

  [
    'type'   => 'multirange',
    'name'   => $prefix . 'camera_pitch_mr',
    'label'  => esc_html__( 'Pitch Range', 'treweler' ),
    'fields' => [
      [
        'name'  => $prefix . 'camera_min_pitch',
        'label' => esc_html__( 'Minimum Pitch', 'treweler' ),
        'value' => [
          'current' => isset( $meta_data->camera_min_pitch ) ? $meta_data->camera_min_pitch : '0',
          'min'     => '0',
          'max'     => '85',
          'step'    => '0.01'
        ],
      ],
      [
        'name'  => $prefix . 'camera_max_pitch',
        'label' => esc_html__( 'Maximum Pitch', 'treweler' ),
        'value' => [
          'current' => isset( $meta_data->camera_max_pitch ) ? $meta_data->camera_max_pitch : '85',
          'min'     => '0',
          'max'     => '85',
          'step'    => '0.01'
        ],
      ]
    ]
  ],
];

$fields_categories = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'category_filter',
    'label' => esc_html__( 'Show Сategory Filter', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'category_filter',
          isset( $meta_data->category_filter ) ? (array) $meta_data->category_filter : [] ),
        'value'   => 'category_filter'
      ]
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'category_position',
    'label' => esc_html__( 'Position', 'treweler' ),
    'id'    => 'twer-category-position',
    'value' => [
      [
        'value'    => 'top-left',
        'label'    => esc_html__( 'Top Left', 'treweler' ),
        'selected' => in_array( 'top-left',
          isset( $meta_data->category_position ) ? (array) $meta_data->category_position : [ 'top-left' ] )
      ],
      [
        'value'    => 'top-right',
        'label'    => esc_html__( 'Top Right', 'treweler' ),
        'selected' => in_array( 'top-right',
          isset( $meta_data->category_position ) ? (array) $meta_data->category_position : [] )
      ],
      [
        'value'    => 'bottom-left',
        'label'    => esc_html__( 'Bottom Left', 'treweler' ),
        'selected' => in_array( 'bottom-left',
          isset( $meta_data->category_position ) ? (array) $meta_data->category_position : [] )
      ],
      [
        'value'    => 'bottom-right',
        'label'    => esc_html__( 'Bottom Right', 'treweler' ),
        'selected' => in_array( 'bottom-right',
          isset( $meta_data->category_position ) ? (array) $meta_data->category_position : [] )
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'show_uncategorized',
    'label' => esc_html__( 'Show Uncategorized', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'show_uncategorized',
          isset( $meta_data->show_uncategorized ) ? (array) $meta_data->show_uncategorized : [ 'show_uncategorized' ] ),
        'value'   => 'show_uncategorized'
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'fitbounds',
    'label' => esc_html__( 'Fit Bounds', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'fitbounds',
          isset( $meta_data->fitbounds ) ? (array) $meta_data->fitbounds : [ 'fitbounds' ] ),
        'value'   => 'fitbounds'
      ]
    ]
  ],
];

$fields_preloader = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'enable_preloader',
    'label' => esc_html__( 'Enable Preloader', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'enable_preloader',
          isset( $meta_data->enable_preloader ) ? (array) $meta_data->enable_preloader : [] ),
        'value'   => 'enable_preloader'
      ]
    ]
  ],
  [
    'type'  => 'colorpicker',
    'name'  => $prefix . 'preloader_background_color',
    'label' => esc_html__( 'Background Color', 'treweler' ),
    'value' => isset( $meta_data->preloader_background_color ) ? $meta_data->preloader_background_color : '#0F0F0F'
  ],
  [
    'type'   => 'textcolorpicker',
    'name'   => $prefix . 'preloader_text_with_color',
    'label'  => esc_html__( 'Preloader Text', 'treweler' ),
    'fields' => [
      [
        'type'  => 'colorpicker',
        'name'  => $prefix . 'preloader_text',
        'label' => esc_html__( 'Text', 'treweler' ),
        'value' => isset( $meta_data->preloader_text ) ? $meta_data->preloader_text : ''
      ],
      [
        'type'  => 'colorpicker',
        'name'  => $prefix . 'preloader_text_color',
        'label' => esc_html__( 'Color', 'treweler' ),
        'value' => isset( $meta_data->preloader_text_color ) ? $meta_data->preloader_text_color : '#FFFFFF',
      ],
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'preloader_enable_percentage',
    'label' => esc_html__( 'Enable Percentage', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'preloader_enable_percentage',
          isset( $meta_data->preloader_enable_percentage ) ? (array) $meta_data->preloader_enable_percentage : [ 'preloader_enable_percentage' ] ),
        'value'   => 'preloader_enable_percentage'
      ]
    ]
  ],
  [
    'type'  => 'colorpicker',
    'name'  => $prefix . 'preloader_percentage_color',
    'label' => esc_html__( 'Percentage Color', 'treweler' ),
    'value' => isset( $meta_data->preloader_percentage_color ) ? $meta_data->preloader_percentage_color : '#4D4D4D'
  ],
  [
    'type'  => 'image',
    'name'  => $prefix . 'preloader_popup_image',
    'label' => esc_html__( 'Image', 'treweler' ),
    'value' => isset( $meta_data->preloader_popup_image ) ? $meta_data->preloader_popup_image : ''
  ],
];

$fields_tour = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'enable_tour',
    'label' => esc_html__( 'Enable Tour', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'enable_tour',
          isset( $meta_data->enable_tour ) ? (array) $meta_data->enable_tour : [] ),
        'value'   => 'enable_tour'
      ]
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'tour_arrows_position',
    'label' => esc_html__( 'Arrows Position', 'treweler' ),
    'id'    => 'twer-tour-arrows-position',
    'value' => [
      [
        'value'    => 'top-left',
        'label'    => esc_html__( 'Top Left', 'treweler' ),
        'selected' => in_array( 'top-left',
          isset( $meta_data->tour_arrows_position ) ? (array) $meta_data->tour_arrows_position : [] )
      ],
      [
        'value'    => 'top-right',
        'label'    => esc_html__( 'Top Right', 'treweler' ),
        'selected' => in_array( 'top-right',
          isset( $meta_data->tour_arrows_position ) ? (array) $meta_data->tour_arrows_position : [] )
      ],
      [
        'value'    => 'bottom-left',
        'label'    => esc_html__( 'Bottom Left', 'treweler' ),
        'selected' => in_array( 'bottom-left',
          isset( $meta_data->tour_arrows_position ) ? (array) $meta_data->tour_arrows_position : [] )
      ],
      [
        'value'    => 'bottom-right',
        'label'    => esc_html__( 'Bottom Right', 'treweler' ),
        'selected' => in_array( 'bottom-right',
          isset( $meta_data->tour_arrows_position ) ? (array) $meta_data->tour_arrows_position : [ 'bottom-right' ] )
      ]
    ]
  ],
  [
    'type'  => 'group-tour-text',
    'name'  => $prefix . 'group_tour_text',
    'label' => esc_html__( 'Tour Information', 'treweler' ),
    'value' => [
      [
        'type'  => 'text',
        'name'  => $prefix . 'tour_start_message',
        'label' => esc_html__( 'Start Message', 'treweler' ),
        'value' => isset( $meta_data->tour_start_message ) ? $meta_data->tour_start_message : ''
      ],
      [
        'type'  => 'checkbox',
        'name'  => $prefix . 'tour_show_marker_names',
        'label' => esc_html__( 'Show Marker Names', 'treweler' ),
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'tour_show_marker_names',
              isset( $meta_data->tour_show_marker_names ) ? (array) $meta_data->tour_show_marker_names : [ 'tour_show_marker_names' ] ),
            'value'   => 'tour_show_marker_names'
          ]
        ]
      ],
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'tour_type',
    'label' => esc_html__( 'Tour Type', 'treweler' ),
    'id'    => 'twer-tour-type',
    'value' => [
      [
        'value'    => 'jump',
        'label'    => esc_html__( 'Jump', 'treweler' ),
        'selected' => in_array( 'jump',
          isset( $meta_data->tour_type ) ? (array) $meta_data->tour_type : [ 'jump' ] )
      ],
      [
        'value'    => 'fly',
        'label'    => esc_html__( 'Fly', 'treweler' ),
        'selected' => in_array( 'fly',
          isset( $meta_data->tour_type ) ? (array) $meta_data->tour_type : [] )
      ],
    ]
  ],
  [
    'type'  => 'range',
    'name'  => $prefix . 'marker_zoom_level',
    'label' => esc_html__( 'Marker Zoom Level', 'treweler' ),
    'value' => [
      'current' => $meta_data->marker_zoom_level ?? ( $meta_data->map_zoom ?? '15' ),
      'min'     => '0',
      'max'     => '24',
      'step'    => '0.01'
    ],
  ],
  [
    'type'  => 'number-v2',
    'name'  => $prefix . 'tour_fly_speed',
    'label' => esc_html__( 'Speed', 'treweler' ),
    'value' => [
      'placeholder' => '1,2',
      'current'     => isset( $meta_data->tour_fly_speed ) ? $meta_data->tour_fly_speed : '',
      'min'         => '0',
      'max'         => '24',
      'step'        => '0.01'
    ],
    'help'  => 'The average speed of the animation defined in relation to the Curve.'
  ],
  [
    'type'  => 'number-v2',
    'name'  => $prefix . 'tour_fly_curve',
    'label' => esc_html__( 'Curve', 'treweler' ),
    'value' => [
      'placeholder' => '1,42',
      'current'     => isset( $meta_data->tour_fly_curve ) ? $meta_data->tour_fly_curve : '',
      'min'         => '0',
      'max'         => '24',
      'step'        => '0.01'
    ],
    'help'  => 'The zooming "curve" that will occur along the flight path.'
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'tour_show_marker_popups',
    'label' => esc_html__( 'Show Marker Popups', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'tour_show_marker_popups',
          isset( $meta_data->tour_show_marker_popups ) ? (array) $meta_data->tour_show_marker_popups : [] ),
        'value'   => 'tour_show_marker_popups'
      ]
    ]
  ],

  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'tour_auto_run',
    'label' => esc_html__( 'Start Tour After Load', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'tour_auto_run',
          isset( $meta_data->tour_auto_run ) ? (array) $meta_data->tour_auto_run : [ 'tour_auto_run' ] ),
        'value'   => 'tour_auto_run'
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'tour_offset',
    'label' => esc_html__( 'Marker Offset', 'treweler' ),
    'value' => [
      [
        'type'        => 'text',
        'name'        => 'top',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '0',
        'label'       => esc_html__( 'Top', 'treweler' ),
        'value'       => isset( $meta_data->tour_offset['top'] ) ? $meta_data->tour_offset['top'] : ''
      ],
      [
        'type'        => 'text',
        'name'        => 'bottom',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '0',
        'label'       => esc_html__( 'Bottom', 'treweler' ),
        'value'       => isset( $meta_data->tour_offset['bottom'] ) ? $meta_data->tour_offset['bottom'] : ''
      ],
      [
        'type'        => 'text',
        'name'        => 'left',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '0',
        'label'       => esc_html__( 'Left', 'treweler' ),
        'value'       => isset( $meta_data->tour_offset['left'] ) ? $meta_data->tour_offset['left'] : ''
      ],
      [
        'type'        => 'text',
        'name'        => 'right',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '0',
        'label'       => esc_html__( 'Right', 'treweler' ),
        'value'       => isset( $meta_data->tour_offset['right'] ) ? $meta_data->tour_offset['right'] : ''
      ],
    ]
  ],
  [
    'type'  => 'tour_markers',
    'name'  => $prefix . 'tour_marker_repeater',
    'label' => esc_html__( 'Tour Markers', 'treweler' ),
    'value' => [
      [
        'type'  => 'text',
        'name'  => 'tour_marker_picker',
        'label' => esc_html__( 'Marker', 'treweler' ),
        'value' => ''
      ],
      [
        'type'  => 'checkbox',
        'name'  => 'tour_advanced_settings',
        'label' => esc_html__( 'Advanced Settings', 'treweler' ),
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'tour_advanced_settings',
              isset( $meta_data->tour_advanced_settings ) ? (array) $meta_data->tour_advanced_settings : [] ),
            'value'   => 'tour_advanced_settings'
          ]
        ]
      ],
      [
        'type'  => 'text',
        'name'  => 'tour_marker_zoom',
        'label' => esc_html__( 'Markers zoom level', 'treweler' ),
        'value' => ''
      ],
      [
        'type'  => 'text',
        'name'  => 'tour_marker_popup',
        'label' => esc_html__( 'Show markers popup', 'treweler' ),
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'tour_marker_popup',
              isset( $meta_data->tour_marker_popup ) ? (array) $meta_data->tour_marker_popup : [] ),
            'value'   => 'tour_marker_popup'
          ]
        ]
      ],
      [
        'type'  => 'text',
        'name'  => 'tour_bearing',
        'label' => esc_html__( 'Bearing', 'treweler' ),
        'value' => ''
      ],
      [
        'type'  => 'text',
        'name'  => 'tour_pitch',
        'label' => esc_html__( 'Pitch', 'treweler' ),
        'value' => ''
      ],
      [
        'type'  => 'group',
        'name'  => 'tour_offset',
        'label' => esc_html__( 'Marker Offset', 'treweler' ),
        'value' => [
          [
            'type'        => 'text',
            'name'        => 'top',
            'postfix'     => 'px',
            'size'        => 'small',
            'placeholder' => '0',
            'label'       => esc_html__( 'Top', 'treweler' ),
            'value'       => isset( $meta_data->tour_offset['top'] ) ? $meta_data->tour_offset['top'] : ''
          ],
          [
            'type'        => 'text',
            'name'        => 'bottom',
            'postfix'     => 'px',
            'size'        => 'small',
            'placeholder' => '0',
            'label'       => esc_html__( 'Bottom', 'treweler' ),
            'value'       => isset( $meta_data->tour_offset['bottom'] ) ? $meta_data->tour_offset['bottom'] : ''
          ],
          [
            'type'        => 'text',
            'name'        => 'left',
            'postfix'     => 'px',
            'size'        => 'small',
            'placeholder' => '0',
            'label'       => esc_html__( 'Left', 'treweler' ),
            'value'       => isset( $meta_data->tour_offset['left'] ) ? $meta_data->tour_offset['left'] : ''
          ],
          [
            'type'        => 'text',
            'name'        => 'right',
            'postfix'     => 'px',
            'size'        => 'small',
            'placeholder' => '0',
            'label'       => esc_html__( 'Right', 'treweler' ),
            'value'       => isset( $meta_data->tour_offset['right'] ) ? $meta_data->tour_offset['right'] : ''
          ],
        ]
      ],
    ]
  ],

];

$fields_languanges = [
  [
    'type'  => 'select',
    'name'  => $prefix . 'map_languanges',
    'label' => esc_html__( 'Languanges', 'treweler' ),
    'id'    => 'twer-map-languanges',
    'value' => [
      [
        'value'    => 'browser',
        'label'    => esc_html__( 'Browser Language', 'treweler' ),
        'selected' => in_array( 'browser',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [ 'browser' ] )
      ],
      [
        'value'    => 'mul',
        'label'    => esc_html__( 'Multilingual', 'treweler' ),
        'selected' => in_array( 'mul',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'ar',
        'label'    => esc_html__( 'Arabic', 'treweler' ),
        'selected' => in_array( 'ar',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'zh-Hans',
        'label'    => esc_html__( 'Chinese Simplified', 'treweler' ),
        'selected' => in_array( 'zh-Hans',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'zh-Hant',
        'label'    => esc_html__( 'Chinese Traditional', 'treweler' ),
        'selected' => in_array( 'zh-Hant',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'en',
        'label'    => esc_html__( 'English', 'treweler' ),
        'selected' => in_array( 'en',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'fr',
        'label'    => esc_html__( 'French', 'treweler' ),
        'selected' => in_array( 'fr',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'de',
        'label'    => esc_html__( 'German', 'treweler' ),
        'selected' => in_array( 'de',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'it',
        'label'    => esc_html__( 'Italian', 'treweler' ),
        'selected' => in_array( 'it',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'ja',
        'label'    => esc_html__( 'Japanese', 'treweler' ),
        'selected' => in_array( 'ja',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'ko',
        'label'    => esc_html__( 'Korean', 'treweler' ),
        'selected' => in_array( 'ko',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'pt',
        'label'    => esc_html__( 'Portuguese', 'treweler' ),
        'selected' => in_array( 'pt',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'ru',
        'label'    => esc_html__( 'Russian', 'treweler' ),
        'selected' => in_array( 'ru',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ],
      [
        'value'    => 'es',
        'label'    => esc_html__( 'Spanish', 'treweler' ),
        'selected' => in_array( 'es',
          isset( $meta_data->map_languanges ) ? (array) $meta_data->map_languanges : [] )
      ]
    ],
    'help'  => esc_html__( 'Language settings are not fully supported for Streets, Outdoors, Satellite and custom styles.',
      'treweler' )
  ],
];


$store_locator_marker_templates = [
  [
    'label'    => esc_html__( 'Select a Template', 'treweler' ),
    'selected' => in_array( 'none',
      isset( $meta_data->store_locator_marker['template'] ) ? (array) $meta_data->store_locator_marker['template'] : [ 'none' ] ),
    'value'    => 'none'
  ],
];
$cpt_templates = get_posts( [
  'post_status'    => 'publish',
  'post_type'      => 'twer-templates',
  'numberposts'    => - 1,
  'posts_per_page' => - 1,
  'order'          => 'ASC',
] );

if ( ! empty( $cpt_templates ) ) {
  foreach ( $cpt_templates as $template ) {
    $template_id = isset( $template->ID ) ? $template->ID : 0;
    $template_label = isset( $template->post_title ) ? $template->post_title : esc_html__( 'Template', 'treweler' );
    $template_selected = in_array( $template_id, isset( $meta_data->store_locator_marker['template'] ) ? (array) $meta_data->store_locator_marker['template'] : [] );

    $store_locator_marker_templates[] = [
      'label'    => $template_label,
      'selected' => $template_selected,
      'value'    => $template_id
    ];
  }
}

$store_locator_radius_size = [
  [
    'label'    => esc_html__( 'Unlimited', 'treweler' ),
    'selected' => in_array( 'unlim',
      isset( $meta_data->store_locator_radius['size'] ) ? (array) $meta_data->store_locator_radius['size'] : [ 'unlim' ] ),
    'value'    => 'unlim'
  ],
];

$ir = 1;
while ( $ir <= 1000 ) {

  switch ( $ir ) {
    case 1 :
    case 5 :
    case 10 :
    case 25 :
    case 50 :
    case 100 :
    case 500 :
      $selected_ir = [ $ir ];
      break;
    default :
      $selected_ir = [];
      break;
  }

  $ir_selected = in_array( $ir, isset( $meta_data->store_locator_radius['size'] ) ? (array) $meta_data->store_locator_radius['size'] : $selected_ir );
  $store_locator_radius_size[] = [
    'label'    => $ir,
    'selected' => $ir_selected,
    'value'    => $ir
  ];

  if ( $ir <= 9 ) {
    $ir ++;
  } elseif ( $ir >= 10 && $ir <= 95 ) {
    $ir += 5;
  } elseif ( $ir >= 100 ) {
    $ir += 50;
  }
}


$store_locator_radius_default_value = isset( $meta_data->store_locator_radius['size'] ) ? (array) $meta_data->store_locator_radius['size'] : [];
$check_value = isset( $store_locator_radius_default_value[0] ) ? $store_locator_radius_default_value[0] : $store_locator_radius_default_value;


if ( is_array( $check_value ) && empty( $check_value ) ) {
  $store_locator_radius_default = [
    [
      'label'    => esc_html__( 'Unlimited', 'treweler' ),
      'selected' => in_array( 'unlim',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [ 'unlim' ] ),
      'value'    => 'unlim'
    ],
    [
      'label'    => esc_html__( '1', 'treweler' ),
      'selected' => in_array( '1',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '1'
    ],
    [
      'label'    => esc_html__( '5', 'treweler' ),
      'selected' => in_array( '5',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '5'
    ],
    [
      'label'    => esc_html__( '10', 'treweler' ),
      'selected' => in_array( '10',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [ '10' ] ),
      'value'    => '10'
    ],
    [
      'label'    => esc_html__( '25', 'treweler' ),
      'selected' => in_array( '25',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '25'
    ],
    [
      'label'    => esc_html__( '50', 'treweler' ),
      'selected' => in_array( '50',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '50'
    ],
    [
      'label'    => esc_html__( '100', 'treweler' ),
      'selected' => in_array( '100',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '100'
    ],
    [
      'label'    => esc_html__( '500', 'treweler' ),
      'selected' => in_array( '500',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => '500'
    ],
  ];
}

if ( is_string( $check_value ) && empty( $check_value ) ) {
  $store_locator_radius_default = [
    [
      'label'    => esc_html__( '10', 'treweler' ),
      'selected' => in_array( '10',
        isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [ '10' ] ),
      'value'    => '10'
    ],
  ];
}

if ( ! empty( $check_value ) ) {

  $store_locator_radius_default = [];
  foreach ( $store_locator_radius_default_value as $store_locator_radius_default_value_item ) {
    $store_locator_radius_default_value_label = $store_locator_radius_default_value_item;
    if ( $store_locator_radius_default_value_label === 'unlim' ) {
      $store_locator_radius_default_value_label = esc_html__( 'Unlimited', 'treweler' );
    }
    $store_locator_radius_default[] = [
      'label'    => $store_locator_radius_default_value_label,
      'selected' => in_array( $store_locator_radius_default_value_item, isset( $meta_data->store_locator_radius_default ) ? (array) $meta_data->store_locator_radius_default : [] ),
      'value'    => $store_locator_radius_default_value_item
    ];
  }
}

$fields_store_locator = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'store_locator',
    'label' => esc_html__( 'Enable Store Locator', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'store_locator',
          isset( $meta_data->store_locator ) ? (array) $meta_data->store_locator : [] ),
        'value'   => 'store_locator'
      ]
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'store_locator_positions',
    'label' => esc_html__( 'Controls Position', 'treweler' ),
    'value' => [
      [
        'value'    => 'top_left',
        'label'    => esc_html__( 'Top Left', 'treweler' ),
        'selected' => in_array( 'top_left',
          isset( $meta_data->store_locator_positions ) ? (array) $meta_data->store_locator_positions : [] )
      ],
      [
        'value'    => 'top_right',
        'label'    => esc_html__( 'Top Right', 'treweler' ),
        'selected' => in_array( 'top_right',
          isset( $meta_data->store_locator_positions ) ? (array) $meta_data->store_locator_positions : [ 'top_right' ] )
      ],
      [
        'value'    => 'bottom_left',
        'label'    => esc_html__( 'Bottom Left', 'treweler' ),
        'selected' => in_array( 'bottom_left',
          isset( $meta_data->store_locator_positions ) ? (array) $meta_data->store_locator_positions : [] )
      ],
      [
        'value'    => 'bottom_right',
        'label'    => esc_html__( 'Bottom Right', 'treweler' ),
        'selected' => in_array( 'bottom_right',
          isset( $meta_data->store_locator_positions ) ? (array) $meta_data->store_locator_positions : [] )
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'store_locator_marker',
    'label' => esc_html__( 'Show Location Marker', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'show',
        'class' => 'col-fixed col-fixed--70 d-flex align-items-center',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'show',
              isset( $meta_data->store_locator_marker['show'] ) ? (array) $meta_data->store_locator_marker['show'] : [ 'show' ] ),
            'value'   => 'show'
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'template',
        'value' => $store_locator_marker_templates
      ],
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'store_locator_search',
    'label' => esc_html__( 'Search Control', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'store_locator_search',
          isset( $meta_data->store_locator_search ) ? (array) $meta_data->store_locator_search : [ 'store_locator_search' ] ),
        'value'   => 'store_locator_search'
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'store_locator_geolocation',
    'label' => esc_html__( 'Geolocation Control', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'store_locator_geolocation',
          isset( $meta_data->store_locator_geolocation ) ? (array) $meta_data->store_locator_geolocation : [ 'store_locator_geolocation' ] ),
        'value'   => 'store_locator_geolocation'
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'store_locator_radius',
    'label' => esc_html__( 'Radius Control', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'show',
        'class' => 'col-fixed col-fixed--70',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'show',
              isset( $meta_data->store_locator_radius['show'] ) ? (array) $meta_data->store_locator_radius['show'] : [ 'show' ] ),
            'value'   => 'show'
          ]
        ]
      ],
      [
        'class' => 'col-fixed col-fixed--550',
        'type'  => 'multiple-select',
        'name'  => 'size',
        'value' => $store_locator_radius_size
      ],
      [
        'type'  => 'select',
        'name'  => 'distance',
        'class' => 'col-fixed col-fixed--90',
        'value' => [
          [
            'value'    => 'kilometers',
            'label'    => esc_html__( 'km', 'treweler' ),
            'selected' => in_array( 'kilometers',
              isset( $meta_data->store_locator_radius['distance'] ) ? (array) $meta_data->store_locator_radius['distance'] : [ 'kilometers' ] )
          ],
          [
            'value'    => 'miles',
            'label'    => esc_html__( 'mi', 'treweler' ),
            'selected' => in_array( 'miles',
              isset( $meta_data->store_locator_radius['distance'] ) ? (array) $meta_data->store_locator_radius['distance'] : [] )
          ],
        ]
      ],
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'store_locator_radius_default',
    'label' => esc_html__( 'Default Radius', 'treweler' ),
    'value' => $store_locator_radius_default
  ],
];


$regions_cap = isset( $meta_data->boundaries_regions ) ? $meta_data->boundaries_regions : 'world';


if ( is_array( $regions_cap ) ) {
  $current_region = isset( $meta_data->boundaries_regions['region'] ) ? $meta_data->boundaries_regions['region'] : 'world';
} else {
  $current_region = $regions_cap;
}


$fields_boundaries = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'boundaries',
    'label' => esc_html__( 'Enable Boundaries', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'boundaries',
          isset( $meta_data->boundaries ) ? (array) $meta_data->boundaries : [] ),
        'value'   => 'boundaries'
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'boundaries_regions',
    'label' => esc_html__( 'Boundaries', 'treweler' ),
    'value' => [
      [
        'type'  => 'select',
        'name'  => 'accuracy',
        'id'    => 'treweler-boundaries-regions-accuracy',
        'label' => esc_html__( 'Accuracy', 'treweler' ),
        'value' => [
          [
            'value'    => 'very_high',
            'label'    => esc_html__( 'Very High', 'treweler' ),
            'selected' => in_array( 'very_high', isset( $meta_data->boundaries_regions['accuracy'] ) ? (array) $meta_data->boundaries_regions['accuracy'] : [] )
          ],
          [
            'value'    => 'high',
            'label'    => esc_html__( 'High', 'treweler' ),
            'selected' => in_array( 'high', isset( $meta_data->boundaries_regions['accuracy'] ) ? (array) $meta_data->boundaries_regions['accuracy'] : [] )
          ],
          [
            'value'    => 'medium',
            'label'    => esc_html__( 'Medium', 'treweler' ),
            'selected' => in_array( 'medium', isset( $meta_data->boundaries_regions['accuracy'] ) ? (array) $meta_data->boundaries_regions['accuracy'] : [ 'medium' ] )
          ],
          [
            'value'    => 'low',
            'label'    => esc_html__( 'Low', 'treweler' ),
            'selected' => in_array( 'low', isset( $meta_data->boundaries_regions['accuracy'] ) ? (array) $meta_data->boundaries_regions['accuracy'] : [] )
          ],
          [
            'value'    => 'very_low',
            'label'    => esc_html__( 'Very Low', 'treweler' ),
            'selected' => in_array( 'very_low', isset( $meta_data->boundaries_regions['accuracy'] ) ? (array) $meta_data->boundaries_regions['accuracy'] : [] )
          ]
        ]
      ],
      [
        'type'  => 'select',
        'name'  => 'region',
        'id'    => 'treweler-boundaries-regions',
        'label' => esc_html__( 'Region', 'treweler' ),
        'atts' => 'data-value="'.esc_attr($current_region).'"',
        'value' => []
      ],
    ]
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_regions_selected',
    'size'  => 'small',
    'label' => esc_html__( 'Region Selected', 'treweler' ),
    'value' => isset( $meta_data->boundaries_regions_selected ) ? $meta_data->boundaries_regions_selected : '[]',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_regions_properties',
    'size'  => 'small',
    'label' => esc_html__( 'Regions Properties', 'treweler' ),
    'value' => isset( $meta_data->boundaries_regions_properties ) ? $meta_data->boundaries_regions_properties : '',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_regions_custom_colors',
    'label' => esc_html__( 'Regions Custom Colors', 'treweler' ),
    'value' => isset( $meta_data->boundaries_regions_custom_colors ) ? $meta_data->boundaries_regions_custom_colors : '[]',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_regions_hide',
    'label' => esc_html__( 'Regions Hide', 'treweler' ),
    'value' => isset( $meta_data->boundaries_regions_hide ) ? $meta_data->boundaries_regions_hide : '[]',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_all_checkboxes',
    'label' => esc_html__( 'All Check Checkboxes States', 'treweler' ),
    'value' => isset( $meta_data->boundaries_all_checkboxes ) ? $meta_data->boundaries_all_checkboxes : '',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_links',
    'label' => esc_html__( 'All links for regions', 'treweler' ),
    'value' => isset( $meta_data->boundaries_links ) ? $meta_data->boundaries_links : '',
  ],
  [
    'type'  => 'text',
    'name'  => $prefix . 'boundaries_values_regions',
    'label' => esc_html__( 'All values for regions', 'treweler' ),
    'value' => isset( $meta_data->boundaries_values_regions ) ? $meta_data->boundaries_values_regions : '',
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'boundaries_fill',
    'label' => esc_html__( 'Fill Color', 'treweler' ),
    'value' => [
      [
        'type'  => 'colorpicker',
        'name'  => 'main',
        'label' => esc_html__( 'Main', 'treweler' ),
        'value' => isset( $meta_data->boundaries_fill['main'] ) ? $meta_data->boundaries_fill['main'] : '#5cc3ff'
      ],
      [
        'type'  => 'colorpicker',
        'name'  => 'hover',
        'label' => esc_html__( 'Hover', 'treweler' ),
        'value' => isset( $meta_data->boundaries_fill['hover'] ) ? $meta_data->boundaries_fill['hover'] : '#32b2fc'
      ],
      [
        'type'  => 'colorpicker',
        'name'  => 'selected',
        'label' => esc_html__( 'Selected', 'treweler' ),
        'value' => isset( $meta_data->boundaries_fill['selected'] ) ? $meta_data->boundaries_fill['selected'] : '#0a88d1'
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'boundaries_stroke',
    'label' => esc_html__( 'Stroke Style', 'treweler' ),
    'value' => [
      [
        'type'  => 'colorpicker',
        'name'  => 'color',
        'label' => '',
        'value' => isset( $meta_data->boundaries_stroke['color'] ) ? $meta_data->boundaries_stroke['color'] : '#004e7b'
      ],
      [
        'type'        => 'text',
        'name'        => 'width',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '1',
        'label'       => '',
        'value'       => isset( $meta_data->boundaries_stroke['width'] ) ? $meta_data->boundaries_stroke['width'] : ''
      ],
    ]
  ],
  [
    'type'  => 'select',
    'name'  => $prefix . 'boundaries_onclick',
    'label' => esc_html__( 'Action On Click', 'treweler' ),
    'value' => [
      [
        'value'    => 'none',
        'label'    => esc_html__( 'None', 'treweler' ),
        'selected' => in_array( 'none',
          isset( $meta_data->boundaries_onclick ) ? (array) $meta_data->boundaries_onclick : [ 'none' ] )
      ],
      [
        'value'    => 'open_link',
        'label'    => esc_html__( 'Open Link', 'treweler' ),
        'selected' => in_array( 'open_link',
          isset( $meta_data->boundaries_onclick ) ? (array) $meta_data->boundaries_onclick : [] )
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'boundaries_onhover',
    'label' => esc_html__( 'Action On Hover', 'treweler' ),
    'value' => [
      [
        'type'  => 'select',
        'name'  => 'type',
        'label' => '',
        'value' => [
          [
            'value'    => 'none',
            'label'    => esc_html__( 'None', 'treweler' ),
            'selected' => in_array( 'none',
              isset( $meta_data->boundaries_onhover['type'] ) ? (array) $meta_data->boundaries_onhover['type'] : [ 'none' ] )
          ],
          [
            'value'    => 'popup',
            'label'    => esc_html__( 'Popup', 'treweler' ),
            'selected' => in_array( 'popup',
              isset( $meta_data->boundaries_onhover['type'] ) ? (array) $meta_data->boundaries_onhover['type'] : [] )
          ],
          [
            'value'    => 'popup_value',
            'label'    => esc_html__( 'Popup with value', 'treweler' ),
            'selected' => in_array( 'popup_value',
              isset( $meta_data->boundaries_onhover['type'] ) ? (array) $meta_data->boundaries_onhover['type'] : [] )
          ]
        ]
      ],
      [
        'type'        => 'text',
        'name'        => 'prefix',
        'placeholder' => esc_html__( 'Prefix', 'treweler' ),
        'label'       => '',
        'value'       => isset( $meta_data->boundaries_onhover['prefix'] ) ? $meta_data->boundaries_onhover['prefix'] : ''
      ],
    ]
  ],
  [
    'type'  => 'table',
    'name'  => $prefix . 'boundaries_polygons',
    'label' => esc_html__( 'Polygon settings', 'treweler' ),
    'value' => [
      [
        'type'  => 'checkbox',
        'name'  => 'active',
        'label' => '',
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'active',
              isset( $meta_data->boundaries_polygons['active'] ) ? (array) $meta_data->boundaries_polygons['active'] : [] ),
            'value'   => 'active'
          ]
        ]
      ],
      [
        'type'        => 'text',
        'name'        => 'name',
        'postfix'     => 'px',
        'size'        => 'small',
        'placeholder' => '',
        'label'       => esc_html__( 'Name', 'treweler' ),
        'value'       => isset( $meta_data->boundaries_polygons['name'] ) ? $meta_data->boundaries_polygons['name'] : ''
      ],
      [
        'type'  => 'colorpicker',
        'name'  => 'color',
        'label' => esc_html__( 'Custom Color', 'treweler' ),
        'value' => isset( $meta_data->boundaries_polygons['color'] ) ? $meta_data->boundaries_polygons['color'] : 'rgba(255, 255, 255, 0)'
      ],
      [
        'type'  => 'checkbox',
        'name'  => 'hide',
        'label' => esc_html__( 'Hide Region', 'treweler' ),
        'value' => [
          [
            'label'   => '',
            'checked' => in_array( 'hide',
              isset( $meta_data->boundaries_polygons['hide'] ) ? (array) $meta_data->boundaries_polygons['hide'] : [] ),
            'value'   => 'hide'
          ]
        ]
      ],
    ]
  ],

];


$fields_restrict_panning = [
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'disable_drag_pan',
    'label' => esc_html__( 'Disable Drag Pan', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'disable_drag_pan',
          isset( $meta_data->disable_drag_pan ) ? (array) $meta_data->disable_drag_pan : [] ),
        'value'   => 'disable_drag_pan'
      ]
    ]
  ],
  [
    'type'  => 'checkbox',
    'name'  => $prefix . 'restrict_panning',
    'label' => esc_html__( 'Enable Restrict Panning', 'treweler' ),
    'value' => [
      [
        'label'   => '',
        'checked' => in_array( 'restrict_panning',
          isset( $meta_data->restrict_panning ) ? (array) $meta_data->restrict_panning : [] ),
        'value'   => 'restrict_panning'
      ]
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'restrict_panning_southwest',
    'label' => esc_html__( 'Southwest', 'treweler' ),
    'value' => [
      [
        'type'        => 'text',
        'name'        => 'lat',
        'size'        => 'small',
        'placeholder' => esc_html__( 'Latitude', 'treweler' ),
        'label'       => '',
        'value'       => isset( $meta_data->restrict_panning_southwest['lat'] ) ? $meta_data->restrict_panning_southwest['lat'] : ''
      ],
      [
        'type'        => 'text',
        'name'        => 'lon',
        'size'        => 'small',
        'placeholder' => esc_html__( 'Longitude', 'treweler' ),
        'label'       => '',
        'value'       => isset( $meta_data->restrict_panning_southwest['lon'] ) ? $meta_data->restrict_panning_southwest['lon'] : ''
      ],
    ]
  ],
  [
    'type'  => 'group',
    'name'  => $prefix . 'restrict_panning_northeast',
    'label' => esc_html__( 'Northeast', 'treweler' ),
    'value' => [
      [
        'type'        => 'text',
        'name'        => 'lat',
        'size'        => 'small',
        'placeholder' => esc_html__( 'Latitude', 'treweler' ),
        'label'       => '',
        'value'       => isset( $meta_data->restrict_panning_northeast['lat'] ) ? $meta_data->restrict_panning_northeast['lat'] : ''
      ],
      [
        'type'        => 'text',
        'name'        => 'lon',
        'size'        => 'small',
        'placeholder' => esc_html__( 'Longitude', 'treweler' ),
        'label'       => '',
        'value'       => isset( $meta_data->restrict_panning_northeast['lon'] ) ? $meta_data->restrict_panning_northeast['lon'] : ''
      ],
    ]
  ],
];

?>
<div class="twer-root">
    <div class="twer-settings">
        <div class="twer-settings__body">
            <div class="container-fluid p-0">
                <div class="row">
                    <div class="col-md-3 col-lg-3 col-xl-2 pr-md-0">
                        <nav class="twer-tabs">
                            <div class="nav nav-tabs" id="twer-nav-tab" role="tablist">
                                <a class="nav-item nav-link active" id="twer-nav-general-tab" data-toggle="tab"
                                   href="#twer-nav-general" role="tab" aria-controls="twer-nav-general"
                                   aria-selected="true"><?php echo esc_html__( 'General', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-categories-tab" data-toggle="tab"
                                   href="#twer-nav-categories" role="tab" aria-controls="twer-nav-categories"
                                   aria-selected="true"><?php echo esc_html__( 'Categories', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-controls-tab" data-toggle="tab"
                                   href="#twer-nav-controls" role="tab" aria-controls="twer-nav-controls"
                                   aria-selected="true"><?php echo esc_html__( 'Controls', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-attribution-tab" data-toggle="tab"
                                   href="#twer-nav-attribution" role="tab" aria-controls="twer-nav-attribution"
                                   aria-selected="false"><?php echo esc_html__( 'Attribution', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-clusters-tab" data-toggle="tab"
                                   href="#twer-nav-clusters" role="tab" aria-controls="twer-nav-clusters"
                                   aria-selected="false"><?php echo esc_html__( 'Clustering', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-lang-tab" data-toggle="tab"
                                   href="#twer-nav-lang" role="tab" aria-controls="twer-nav-lang"
                                   aria-selected="false"><?php echo esc_html__( 'Languages', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-widgets-tab" data-toggle="tab"
                                   href="#twer-nav-widgets" role="tab" aria-controls="twer-nav-widgets"
                                   aria-selected="false"><?php echo esc_html__( 'Information Widgets',
                                    'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-camera-tab" data-toggle="tab"
                                   href="#twer-nav-camera" role="tab" aria-controls="twer-nav-camera"
                                   aria-selected="false"><?php echo esc_html__( 'Pitch & Bearing',
                                    'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-restrict-panning-tab" data-toggle="tab"
                                   href="#twer-nav-restrict-panning" role="tab" aria-controls="twer-nav-restrict-panning"
                                   aria-selected="false"><?php echo esc_html__( 'Restrict Panning', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-preloader-tab" data-toggle="tab"
                                   href="#twer-nav-preloader" role="tab" aria-controls="twer-nav-preloader"
                                   aria-selected="false"><?php echo esc_html__( 'Preloader',
                                    'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-tour-tab" data-toggle="tab"
                                   href="#twer-nav-tour" role="tab" aria-controls="twer-nav-tour"
                                   aria-selected="false"><?php echo esc_html__( 'Tour',
                                    'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-store-locator-tab" data-toggle="tab"
                                   href="#twer-nav-store-locator" role="tab" aria-controls="twer-nav-store-locator"
                                   aria-selected="false"><?php echo esc_html__( 'Store Locator', 'treweler' ); ?></a>
                                <a class="nav-item nav-link" id="twer-nav-boundaries-tab" data-toggle="tab"
                                   href="#twer-nav-boundaries" role="tab" aria-controls="twer-nav-boundaries"
                                   aria-selected="false"><?php echo esc_html__( 'Boundaries', 'treweler' ); ?></a>
                            </div>
                        </nav>
                    </div>
                    <div class="col-md-9 col-lg-9 col-xl-10 pl-md-0">
                        <div class="tab-content" id="twer-Nav-tabContent">
                            <div class="tab-pane fade show active" id="twer-nav-general" role="tabpanel"
                                 aria-labelledby="twer-nav-general-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>


                                        <tr class="section-map-info">
                                            <th>
                                                <label for="treweler_map_projection">
                                                  <?php echo esc_html__( 'Map Projection', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                                <div class="twer-form-group twer-form-group--select">
                                                    <select class="large-select"
                                                            name="_treweler_map_projection"
                                                            id="treweler_map_projection">
<option value="mercator" <?php echo ( $projection === 'mercator' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Mercator', 'treweler' ); ?></option>
<option value="globe" <?php echo ( $projection === 'globe' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Globe', 'treweler' ); ?></option>
<option value="equirectangular" <?php echo ( $projection === 'equirectangular' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Equirectangular', 'treweler' ); ?></option>
<option value="lambertConformalConic" <?php echo ( $projection === 'lambertConformalConic' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Lambert Conformal Conic', 'treweler' ); ?></option>
<option value="albers" <?php echo ( $projection === 'albers' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Albers', 'treweler' ); ?></option>
<option value="winkelTripel" <?php echo ( $projection === 'winkelTripel' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Winkel Tripel', 'treweler' ); ?></option>
<option value="naturalEarth" <?php echo ( $projection === 'naturalEarth' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Natural Earth', 'treweler' ); ?></option>
<option value="equalEarth" <?php echo ( $projection === 'equalEarth' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Equal Earth', 'treweler' ); ?></option>

                                                    </select>
                                                </div>
                                            </td>
                                        </tr>

                                        <tr>
                                            <th>
                                                <label for="show-map-desc">
                                                  <?php echo esc_html__( 'Show Map Description', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                              <?php
                                              $desc_checked = in_array( 'show_map_desc',
                                                isset( $meta_data->show_map_desc ) ? (array) $meta_data->show_map_desc : [] );
                                              ?>
                                                <div class="twer-form-group twer-form-group--checkbox">
                                                    <input type="hidden" name="<?php echo $prefix . 'show_map_desc'; ?>"
                                                           value="">
                                                    <label for="show-map-desc" class="twer-switcher">
                                                        <input id="show-map-desc" type="checkbox"
                                                               name="<?php echo $prefix . 'show_map_desc'; ?>[]"
                                                               value="show_map_desc" <?php checked( $desc_checked ); ?>>
                                                        <div class="twer-switcher__slider"></div>
                                                    </label>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr class="section-map-info row-block">
                                          <?php
                                          $map_name_font_size = $meta_data->map_name_font_size ?? '';
                                          $map_name_font_weight = $meta_data->map_name_font_weight ?? '400';
                                          $map_desc_font_size = $meta_data->map_desc_font_size ?? '';
                                          $map_desc_font_weight = $meta_data->map_desc_font_weight ?? '400';
                                          //
                                          //											$font_weight_mapping = [
                                          //												'100' => 'Thin',
                                          //												'200' => 'Extra Light',
                                          //												'300' => 'Light',
                                          //												'400' => 'Regular',
                                          //												'600' => 'Semi Bold',
                                          //												'700' => 'Bold',
                                          //												'800' => 'Extra Bold',
                                          //												'900' => 'Black',
                                          //											];

                                          ?>
                                            <th>
                                                <label for="treweler_mapbox_access_token">
                                                  <?php echo esc_html__( 'Map Name', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                                <div class="row">
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <input type="text" name="_treweler_map_details_name"
                                                                   id="map_name"
                                                                   class="large-text"
                                                                   value="<?php echo esc_attr( htmlspecialchars( $name ) ) ?>">
                                                        </div>
                                                    </div>
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <div class="map-text-color" id="map-text-color-name">
                                                    <span class="color-holder"
                                                          style="background-color:<?php echo esc_attr( $name_color ); ?>;"></span>
                                                                <input type="button" id="text-name-color-picker-btn"
                                                                       class="text-color-picker-btn"
                                                                       value="<?php echo esc_attr__( 'Select Color',
                                                                         'treweler' ); ?>">
                                                            </div>
                                                            <div class="color-picker-text-name"
                                                                 acp-color="<?php echo esc_attr( $name_color ); ?>"
                                                                 acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                 default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                 acp-show-rgb="no"
                                                                 acp-show-hsl="no"
                                                                 acp-palette-editable>
                                                            </div>
                                                            <input type="hidden" name="_treweler_map_details_name_color"
                                                                   class="input-color" id="map_name_color"
                                                                   value="<?php echo esc_attr( $name_color ); ?>">
                                                            <input type="hidden" name="addCustomColor" id="addCustomColor" value="<?php echo esc_attr( $custom_color ); ?>"/>
                                                        </div>
                                                    </div>
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <!-- Font Size -->
                                                            <div class="twer-form-group twer-form-group--text twer-form-group--small twer-form-group--append">
                                                                <input type="number"
                                                                       min="2"
                                                                       max="100"
                                                                       id="map-name-font-size"
                                                                       name="_treweler_map_name_font_size"
                                                                       class="large-text"
                                                                       value="<?php echo esc_attr( $map_name_font_size ) ?>"
                                                                       placeholder="15">
                                                                <div class="twer-form-group-append">
                                                                    <span class="twer-form-group-append__text">px</span>
                                                                </div>
                                                            </div>
                                                            <!-- End Font Size -->
                                                        </div>
                                                    </div>

                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <!-- Font Weight -->
                                                            <div class="twer-form-group twer-form-group--select">
                                                                <select class="large-select"
                                                                        name="_treweler_map_name_font_weight"
                                                                        id="map_name_font_weight">

                                                                    <option value="100" <?php echo ( $map_name_font_weight === '100' ) ? 'selected' : '' ?>>
                                                                        Thin 100
                                                                    </option>
                                                                    <option value="200" <?php echo ( $map_name_font_weight === '200' ) ? 'selected' : '' ?>>
                                                                        Extra Light 200
                                                                    </option>
                                                                    <option value="300" <?php echo ( $map_name_font_weight === '300' ) ? 'selected' : '' ?>>
                                                                        Light 300
                                                                    </option>
                                                                    <option value="400" <?php echo ( $map_name_font_weight === '400' ) ? 'selected' : '' ?>>
                                                                        Regular 400
                                                                    </option>
                                                                    <option value="500" <?php echo ( $map_name_font_weight === '500' ) ? 'selected' : '' ?>>
                                                                        Medium 500
                                                                    </option>
                                                                    <option value="600" <?php echo ( $map_name_font_weight === '600' ) ? 'selected' : '' ?>>
                                                                        Semi Bold 600
                                                                    </option>
                                                                    <option value="700" <?php echo ( $map_name_font_weight === '700' ) ? 'selected' : '' ?>>
                                                                        Bold 700
                                                                    </option>
                                                                    <option value="800" <?php echo ( $map_name_font_weight === '800' ) ? 'selected' : '' ?>>
                                                                        Extra Bold 800
                                                                    </option>
                                                                    <option value="900" <?php echo ( $map_name_font_weight === '900' ) ? 'selected' : '' ?>>
                                                                        Black 900
                                                                    </option>

                                                                </select>
                                                            </div>
                                                            <!-- End Font Weight -->
                                                        </div>
                                                    </div>
                                                </div>


                                            </td>
                                        </tr>


                                        <tr class="section-map-info row-block">

                                            <th>
                                                <label for="treweler_mapbox_access_token">
                                                  <?php echo esc_html__( 'Map Description', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                                <div class="row">
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <input type="text" name="_treweler_map_details_description"
                                                                   id="map_description" class="large-text"
                                                                   value="<?php echo esc_attr( htmlspecialchars( $desc ) ) ?>">
                                                        </div>
                                                    </div>
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <div class="map-text-color" id="map-text-color-descr">
                                                    <span class="color-holder"
                                                          style="background-color:<?php echo esc_attr( $desc_color ); ?>;"></span>
                                                                <input type="button" id="text-descr-color-picker-btn"
                                                                       class="text-color-picker-btn"
                                                                       value="<?php echo esc_attr__( 'Select Color',
                                                                         'treweler' ); ?>">
                                                            </div>
                                                            <div class="color-picker-text-descr"
                                                                 acp-color="<?php echo esc_attr( $desc_color ); ?>"
                                                                 acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                 default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                 acp-show-rgb="no"
                                                                 acp-show-hsl="no"
                                                                 acp-palette-editable>
                                                            </div>
                                                            <input type="hidden"
                                                                   name="_treweler_map_details_description_color"
                                                                   class="input-color" id="map_description_color"
                                                                   value="<?php echo esc_attr( $desc_color ); ?>">
                                                        </div>
                                                    </div>
                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <!-- Font Size -->
                                                            <div class="twer-form-group twer-form-group--text twer-form-group--small twer-form-group--append">
                                                                <input type="number"
                                                                       min="2"
                                                                       max="100"
                                                                       id="map-name-font-size"
                                                                       name="_treweler_map_desc_font_size"
                                                                       class="large-text"
                                                                       value="<?php echo esc_attr( $map_desc_font_size ) ?>"
                                                                       placeholder="12">
                                                                <div class="twer-form-group-append">
                                                                    <span class="twer-form-group-append__text">px</span>
                                                                </div>
                                                            </div>
                                                            <!-- End Font Size -->
                                                        </div>
                                                    </div>

                                                    <div class="t-col">
                                                        <div class="field-wrapper">
                                                            <!-- Font Weight -->
                                                            <div class="twer-form-group twer-form-group--select">
                                                                <select class="large-select"
                                                                        name="_treweler_map_desc_font_weight"
                                                                        id="map_desc_font_weight">

                                                                    <option value="100" <?php echo ( $map_desc_font_weight === '100' ) ? 'selected' : '' ?>>
                                                                        Thin 100
                                                                    </option>
                                                                    <option value="200" <?php echo ( $map_desc_font_weight === '200' ) ? 'selected' : '' ?>>
                                                                        Extra Light 200
                                                                    </option>
                                                                    <option value="300" <?php echo ( $map_desc_font_weight === '300' ) ? 'selected' : '' ?>>
                                                                        Light 300
                                                                    </option>
                                                                    <option value="400" <?php echo ( $map_desc_font_weight === '400' ) ? 'selected' : '' ?>>
                                                                        Regular 400
                                                                    </option>
                                                                    <option value="500" <?php echo ( $map_desc_font_weight === '500' ) ? 'selected' : '' ?>>
                                                                        Medium 500
                                                                    </option>
                                                                    <option value="600" <?php echo ( $map_desc_font_weight === '600' ) ? 'selected' : '' ?>>
                                                                        Semi Bold 600
                                                                    </option>
                                                                    <option value="700" <?php echo ( $map_desc_font_weight === '700' ) ? 'selected' : '' ?>>
                                                                        Bold 700
                                                                    </option>
                                                                    <option value="800" <?php echo ( $map_desc_font_weight === '800' ) ? 'selected' : '' ?>>
                                                                        Extra Bold 800
                                                                    </option>
                                                                    <option value="900" <?php echo ( $map_desc_font_weight === '900' ) ? 'selected' : '' ?>>
                                                                        Black 900
                                                                    </option>

                                                                </select>
                                                            </div>
                                                            <!-- End Font Weight -->
                                                        </div>
                                                    </div>
                                                </div>


                                            </td>
                                        </tr>

                                        <tr class="section-map-info">
                                            <th>
                                                <label for="treweler_mapbox_access_token">
                                                  <?php echo esc_html__( 'Position', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                                <div class="twer-form-group twer-form-group--select">
                                                    <select class="large-select"
                                                            name="_treweler_map_details_position"
                                                            id="descr_position">
                                                        <option value="top_left" <?php echo ( $position == 'top_left' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Top Left',
                                                            'treweler' ); ?></option>
                                                        <option value="top_right" <?php echo ( $position == 'top_right' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Top Right',
                                                            'treweler' ); ?></option>
                                                        <option value="bottom_left" <?php echo ( $position == 'bottom_left' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Bottom Left',
                                                            'treweler' ); ?></option>
                                                        <option value="bottom_right" <?php echo ( $position == 'bottom_right' ) ? 'selected' : '' ?>><?php echo esc_html__( 'Bottom Right',
                                                            'treweler' ); ?></option>
                                                    </select>
                                                </div>
                                            </td>
                                        </tr>
                                        <tr class="section-map-info">
                                            <th>
                                                <label for="map-main-logo">
                                                  <?php echo esc_html__( 'Map Logo', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>


                                                <div class="twer-attach js-twer-attach-wrap">

                                                    <div class="twer-attach__thumb js-twer-attach-thumb">
                                                      <?php

                                                      $map_logo = isset( $meta_data->map_main_logo ) ? $meta_data->map_main_logo : '';
                                                      if ( is_numeric( $map_logo ) ) {
                                                        $attachment = wp_get_attachment_image_src( $map_logo, 'full' );
                                                        $attachment = isset( $attachment[0] ) ? $attachment[0] : $map_logo;
                                                      } else {
                                                        $attachment = $map_logo;
                                                      }

                                                      if ( ! empty( $map_logo ) ) { ?>
                                                          <img src="<?php echo esc_url( $attachment ); ?>" alt="">
                                                      <?php } ?>
                                                        <button type="button"
                                                                id="<?php echo esc_attr( 'map-main-logo' ); ?>"
                                                                style="<?php echo ! empty( $map_logo ) ? 'display:none;' : 'display:block'; ?>"
                                                                class="twer-attach__add-media js-twer-attach-add">
                                                          <?php echo esc_html__( 'Select Image',
                                                            'treweler' ); ?>
                                                        </button>

                                                        <input type="hidden"
                                                               name="<?php echo esc_attr( $prefix . 'map_main_logo' ); ?>"
                                                               value="<?php echo esc_attr( $map_logo ); ?>">
                                                    </div>

                                                    <div class="twer-attach__actions js-twer-attach-actions"
                                                         style="<?php echo ! empty( $map_logo ) ? 'display:block;' : 'display:none'; ?>">
                                                        <button type="button"
                                                                class="button js-twer-attach-remove"><?php echo esc_html__( 'Remove',
                                                            'treweler' ); ?></button>
                                                        <button type="button"
                                                                class="button js-twer-attach-add"><?php echo esc_html__( 'Change image',
                                                            'treweler' ); ?></button>
                                                    </div>
                                                </div>


                                            </td>
                                        </tr>


                                        <tr class="section-map-info">
                                            <th>
                                                <label for="treweler_mapbox_logo-size">
                                                  <?php echo esc_html__( 'Logo Size', 'treweler' ); ?>
                                                </label>
                                            </th>
                                            <td>
                                                <div class="twer-form-group twer-form-group--text twer-form-group--small twer-form-group--append">
                                                    <input type="text" id="treweler_mapbox_logo-size" name="_treweler_map_details_logo_size" class="large-text" value="<?php echo esc_attr( $logoSize ); ?>" placeholder="40">
                                                    <div class="twer-form-group-append">
                                                        <span class="twer-form-group-append__text">px</span>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>


                                        <?php

                                        $logo_url = get_post_meta( $post_id, '_treweler_map_logo_url', true );
                                        $logo_target = get_post_meta( $post_id, '_treweler_map_logo_target', true );
                                        if ( is_array( $logo_target ) ) {
                                          $logo_target = $logo_target[0];
                                        }


                                        ?>
                                        <tr class="twer-tr-toggle">
                                            <th class="th-treweler-popup-button">
                                                <label for="treweler-popup-button"><?php echo esc_html__( 'Link', 'treweler' ); ?></label>
                                            </th>
                                            <td>
                                                <div class="twer-group-elements">
                                                    <div class="row">

                                                        <div class="col-fixed col-fixed--260">
                                                            <label for="treweler-map-logo-url"><?php echo esc_html__( 'URL', 'treweler' ); ?></label>
                                                            <div class="twer-form-group twer-form-group--text ">
                                                                <input type="url" id="treweler-map-logo-url" name="_treweler_map_logo_url" class="large-text" value="<?php echo esc_url( $logo_url ); ?>">
                                                            </div>


                                                        </div>

                                                        <div class="col-fixed">
                                                            <label for="treweler-map-logo-target"><?php echo esc_html__( 'Open in new tab', 'treweler' ); ?></label>
                                                            <input type="hidden" name="_treweler_map_logo_target" value="">
                                                            <label for="treweler-map-logo-target" class="twer-switcher">
                                                                <input type="checkbox" <?php checked( $logo_target, 'target' ); ?> name="_treweler_map_logo_target[]" id="treweler-map-logo-target" value="target">
                                                                <div class="twer-switcher__slider"></div>
                                                            </label>
                                                        </div>
                                                    </div>
                                                </div>
                                            </td>
                                        </tr>

                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            <div class="tab-pane fade" id="twer-nav-categories" role="tabpanel"
                                 aria-labelledby="twer-nav-categories-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">

                                        <tbody>
                                        <?php foreach ( $fields_categories as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'number-v2' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                      </div>

                                                  <?php } elseif ( 'range' === $field['type'] ) {

                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                        <span class="color-holder"
                              style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>


                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>


                                    </table>
                                </div>
                            </div>


                            <div class="tab-pane fade" id="twer-nav-controls" role="tabpanel"
                                 aria-labelledby="twer-nav-controls-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">

                                        <tbody>
                                        <?php foreach ( $fields_controls as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'number-v2' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                      </div>

                                                  <?php } elseif ( 'range' === $field['type'] ) {

                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                        <span class="color-holder"
                              style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>


                                                  <?php } elseif ( 'group' === $field['type'] ) { ?>
                                                      <div class="twer-group-elements">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $field_group ) {

                                                              $element_id_group = trim( str_replace( '_', '-',
                                                                $field['name'] . '_' . $field_group['name'] ),
                                                                '-' );
                                                              $field_group['name'] = $field['name'] . '[' . $field_group['name'] . ']';

                                                              $field_class = [];
                                                              if ( isset( $field_group['postfix'] ) ) {
                                                                $field_class[] = 'twer-form-group--append';
                                                              }

                                                              $group_class = isset( $field_group['class'] ) ? $field_group['class'] : 'col-fixed';

                                                              ?>
                                                                <div class="<?php echo 'colorpicker' === $field_group['type'] ? 'col-simple' : $group_class ?>">
                                                                  <?php if ( ! empty( $field_group['label'] ) ) { ?>
                                                                      <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                  <?php } ?>
                                                                  <?php if ( 'text' === $field_group['type'] || 'url' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--text <?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                                          <input type="<?php echo esc_attr( $field_group['type'] ); ?>"
                                                                                 id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="large-text"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>">
                                                                        <?php if ( isset( $field_group['postfix'] ) ) { ?>
                                                                            <div class="twer-form-group-append">
                                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field_group['postfix'] ); ?></span>
                                                                            </div>
                                                                        <?php } ?>
                                                                      </div>


                                                                  <?php } elseif ( 'select' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--select">
                                                                          <select name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                  class="large-select"
                                                                                  id="<?php echo esc_attr( $element_id_group ); ?>">
                                                                            <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                                            <?php } ?>
                                                                          </select>
                                                                      </div>


                                                                  <?php } elseif ( 'colorpicker' === $field_group['type'] ) { ?>
                                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                                          <div class="map-text-color js-twer-color-picker">
                                                                                    <span class="color-holder"
                                                                                          style="background-color:<?php echo esc_attr( $field_group['value'] ) ?>;"></span>
                                                                              <input type="button"
                                                                                     class="text-color-picker-btn"
                                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                                       'treweler' ); ?>">
                                                                          </div>
                                                                          <!-- .color-picker-text-descr -->
                                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                                               acp-color="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                               acp-show-rgb="no"
                                                                               acp-show-hsl="no"
                                                                               acp-palette-editable>
                                                                          </div>
                                                                          <input type="hidden"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="input-color"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>">
                                                                      </div>
                                                                  <?php } elseif ( 'checkbox' === $field_group['type'] ) { ?>
                                                                      <input type="hidden"
                                                                             name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                             value="">
                                                                    <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                          <label for="<?php echo esc_attr( $element_id_group ) ?>"
                                                                                 class="twer-switcher">
                                                                              <input type="checkbox"
                                                                                     name="<?php echo esc_attr( $field_group['name'] ); ?>[]"
                                                                                     id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                                              <div class="twer-switcher__slider"></div>
                                                                          </label>
                                                                    <?php } ?>
                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>


                                    </table>
                                </div>
                            </div>


                            <div class="tab-pane fade" id="twer-nav-attribution" role="tabpanel"
                                 aria-labelledby="twer-nav-attribution-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_attribution as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr>
                                                <th>
                                                    <label for="<?php echo esc_attr( $field['id'] ); ?>">
                                                      <?php echo esc_html( $field['label'] ); ?>
                                                    </label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  id="<?php echo esc_attr( $field['id'] ); ?>"
                                                                  class="large-select">
                                                            <?php foreach ( $field['value'] as $value => $data ) { ?>
                                                                <option value="<?php echo esc_attr( $value ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['title'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $value => $data ) { ?>
                                                          <label class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $field['id'] ); ?>"
                                                                     value="<?php echo esc_attr( $value ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['title'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>


                            <!-- end twer nav clusters -->
                            <div class="tab-pane fade" id="twer-nav-clusters" role="tabpanel"
                                 aria-labelledby="twer-nav-clusters-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_clusters as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr>
                                                <th>
                                                    <label for="<?php echo esc_attr( $element_id ); ?>">
                                                      <?php echo esc_html( $field['label'] ); ?>
                                                    </label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  id="<?php echo esc_attr( $element_id ); ?>"
                                                                  class="large-select">
                                                            <?php foreach ( $field['value'] as $value => $data ) { ?>
                                                                <option value="<?php echo esc_attr( $value ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['title'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'text' === $field['type'] ) {

                                                    $field_class = [ 'twer-form-group twer-form-group--text' ];
                                                    $field_placeholder = '';
                                                    if ( isset( $field['size'] ) ) {
                                                      $field_class[] = 'twer-form-group--' . $field['size'];
                                                    }

                                                    if ( isset( $field['placeholder'] ) ) {
                                                      $field_placeholder = $field['placeholder'];
                                                    }
                                                    if ( isset( $field['postfix'] ) ) {
                                                      $field_class[] = 'twer-form-group--append';
                                                    }

                                                    ?>
                                                      <div class="<?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                          <input type="text"
                                                                 name="<?php echo esc_attr( $field['name'] ) ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 class="large-text"
                                                                 value="<?php echo esc_attr( htmlspecialchars( $field['value'] ) ) ?>"
                                                                 placeholder="<?php echo esc_attr( $field_placeholder ); ?>"
                                                          >
                                                        <?php if ( isset( $field['postfix'] ) ) { ?>
                                                            <div class="twer-form-group-append">
                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field['postfix'] ); ?></span>
                                                            </div>
                                                        <?php } ?>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            <!-- Languange -->
                            <div class="tab-pane fade" id="twer-nav-lang" role="tabpanel"
                                 aria-labelledby="twer-nav-lang-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_languanges as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                    <div class="twer-form-group twer-form-group--select twer-form-group--select-group">
                                                        <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                class="large-select"
                                                                id="<?php echo esc_attr( $element_id ); ?>">
                                                          <?php foreach ( $field['value'] as $data ) { ?>
                                                              <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                          <?php } ?>
                                                        </select>
                                                      <?php if ( ! empty( $field['help'] ) ) { ?>
                                                          <a href="#" class="twer-help-tooltip"
                                                             data-toggle="tooltip"
                                                             title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                      class="dashicons dashicons-editor-help"></span></a>
                                                      <?php } ?>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            <!-- End of Languange -->

                            <div class="tab-pane fade" id="twer-nav-widgets" role="tabpanel"
                                 aria-labelledby="twer-nav-widgets-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_widgets as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr>
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'range' === $field['type'] ) {


                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>
                                                  <?php } elseif ( 'widgets' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                             value="">
                                                      <div class="twer-widgets js-twer-widgets">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $widgets_area ) {
                                                              $cols = count( $field['value'] );
                                                              ?>
                                                                <div class="col-lg-<?php echo esc_attr( 12 / $cols ); ?>">
                                                                  <?php foreach ( $widgets_area as $element ) { ?>
                                                                      <div class="widget js-twer-widget">
                                                                          <div class="widget-top js-twer-widget-handle">
                                                                              <div class="widget-title-action">
                                                                                  <button type="button"
                                                                                          class="widget-action hide-if-no-js"
                                                                                          aria-expanded="false">
                                                                                            <span class="toggle-indicator"
                                                                                                  aria-hidden="true"></span>
                                                                                  </button>
                                                                              </div>
                                                                              <div class="widget-title">
                                                                                  <h3><?php echo esc_html( $element['label'] ) ?>
                                                                                      <span class="in-widget-title"></span>
                                                                                  </h3></div>
                                                                          </div>

                                                                          <div class="widget-inside">
                                                                            <?php if ( 'widget' === $element['type'] ) {

                                                                              $id_repeater = trim( str_replace( '_',
                                                                                '-',
                                                                                "{$field['name']}-{$element['name']}" ),
                                                                                '-' );
                                                                              ?>
                                                                                <div class="widget-content">
                                                                                    <div class="twer-subwidgets">
                                                                                        <template
                                                                                                class="twer-repeater-template js-twer-repeater-template">
                                                                                            <div class="widget js-twer-widget">
                                                                                                <div class="widget-top js-twer-widget-handle js-twer-widget-ui-handle ui-sortable-handle">
                                                                                                    <div class="widget-title-action">
                                                                                                        <button type="button"
                                                                                                                class="widget-action hide-if-no-js"
                                                                                                                aria-expanded="false">
                                                                                                                    <span class="toggle-indicator"
                                                                                                                          aria-hidden="true"></span>
                                                                                                        </button>
                                                                                                    </div>
                                                                                                    <div class="widget-title">
                                                                                                        <h3>
                                                                                                            <span class="js-twer-title-widget">&nbsp;</span><span
                                                                                                                    class="in-widget-title"></span>
                                                                                                        </h3>
                                                                                                    </div>
                                                                                                </div>

                                                                                                <div class="widget-inside">
                                                                                                    <div class="widget-content">
                                                                                                        <div class="table-responsive">
                                                                                                            <table class="table table-borderless">
                                                                                                                <tbody>
                                                                                                                <?php foreach ( $element['value'] as $field_value ) {
                                                                                                                  $name = "{$field['name']}[{$element['name']}][%index%][{$field_value['name']}]";
                                                                                                                  $id = trim( str_replace( '--',
                                                                                                                    '-',
                                                                                                                    str_replace( [
                                                                                                                      '[',
                                                                                                                      ']',
                                                                                                                      '_'
                                                                                                                    ],
                                                                                                                      '-',
                                                                                                                      $name ) ),
                                                                                                                    '-' );
                                                                                                                  $class = 'description' === $field_value['name'] ? 'js-twer-dynamic-' . $field_value['name'] : '';
                                                                                                                  ?>
                                                                                                                    <tr>
                                                                                                                        <th>
                                                                                                                            <label for="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( $field_value['label'] ); ?></label>
                                                                                                                        </th>
                                                                                                                        <td>
                                                                                                                          <?php if ( 'text' === $field_value['type'] ) { ?>
                                                                                                                              <input type="text"
                                                                                                                                     data-id="<?php echo esc_attr( $id ); ?>"
                                                                                                                                     class="large-text <?php echo esc_attr( $class ); ?>"
                                                                                                                                     data-name="<?php echo esc_attr( $name ); ?>"
                                                                                                                                     value="">
                                                                                                                          <?php } ?>
                                                                                                                        </td>
                                                                                                                    </tr>
                                                                                                                <?php } ?>
                                                                                                                </tbody>
                                                                                                            </table>
                                                                                                        </div>

                                                                                                    </div>

                                                                                                    <div class="widget-control-actions">
                                                                                                        <div class="alignright">
                                                                                                            <button type="button"
                                                                                                                    class="button-link button-link-delete widget-control-remove js-twer-remove-widget"><?php echo esc_html__( 'Remove',
                                                                                                                'treweler' ); ?></button>
                                                                                                        </div>
                                                                                                        <br class="clear">
                                                                                                    </div>

                                                                                                </div>

                                                                                                <div class="widget-description"></div>
                                                                                            </div>
                                                                                        </template>

                                                                                        <div data-position="<?php echo esc_attr( $element['name'] ) ?>"
                                                                                             id="<?php echo esc_attr( $id_repeater ); ?>"
                                                                                             class="twer-repeater js-twer-repeater js-twer-ui-repeater ui-sortable">

                                                                                          <?php

                                                                                          $widgets_values = ! empty( $meta_data->widgets[ $element['name'] ] ) ? array_values( $meta_data->widgets[ $element['name'] ] ) : [];

                                                                                          if ( $widgets_values ) {
                                                                                            foreach ( $widgets_values as $widget_index => $widget_values ) {
                                                                                              $widget_head = isset( $widget_values['description'] ) ? $widget_values['description'] : '&nbsp;';
                                                                                              ?>
                                                                                                <div class="widget js-twer-widget">
                                                                                                    <div class="widget-top js-twer-widget-handle js-twer-widget-ui-handle ui-sortable-handle">
                                                                                                        <div class="widget-title-action">
                                                                                                            <button type="button"
                                                                                                                    class="widget-action hide-if-no-js"
                                                                                                                    aria-expanded="false">
                                                                                                                            <span class="toggle-indicator"
                                                                                                                                  aria-hidden="true"></span>
                                                                                                            </button>
                                                                                                        </div>
                                                                                                        <div class="widget-title">
                                                                                                            <h3>
                                                                                                                <span class="js-twer-title-widget"><?php echo esc_html( $widget_head ); ?></span><span
                                                                                                                        class="in-widget-title"></span>
                                                                                                            </h3>
                                                                                                        </div>
                                                                                                    </div>

                                                                                                    <div class="widget-inside">
                                                                                                        <div class="widget-content">
                                                                                                            <div class="table-responsive">
                                                                                                                <table class="table table-borderless">
                                                                                                                    <tbody>
                                                                                                                    <?php foreach ( $element['value'] as $field_value ) {
                                                                                                                      $name = "{$field['name']}[{$element['name']}][{$widget_index}][{$field_value['name']}]";
                                                                                                                      $id = trim( str_replace( '--',
                                                                                                                        '-',
                                                                                                                        str_replace( [
                                                                                                                          '[',
                                                                                                                          ']',
                                                                                                                          '_'
                                                                                                                        ],
                                                                                                                          '-',
                                                                                                                          $name ) ),
                                                                                                                        '-' );
                                                                                                                      $class = 'description' === $field_value['name'] ? 'js-twer-dynamic-' . $field_value['name'] : '';
                                                                                                                      ?>
                                                                                                                        <tr>
                                                                                                                            <th>
                                                                                                                                <label for="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( $field_value['label'] ); ?></label>
                                                                                                                            </th>
                                                                                                                            <td>
                                                                                                                              <?php if ( 'text' === $field_value['type'] ) {
                                                                                                                                $widget_value = isset( $widget_values[ $field_value['name'] ] ) ? $widget_values[ $field_value['name'] ] : '';
                                                                                                                                ?>
                                                                                                                                  <input type="text"
                                                                                                                                         id="<?php echo esc_attr( $id ); ?>"
                                                                                                                                         class="large-text <?php echo esc_attr( $class ); ?>"
                                                                                                                                         name="<?php echo esc_attr( $name ); ?>"
                                                                                                                                         value="<?php echo esc_attr( $widget_value ); ?>">
                                                                                                                              <?php } ?>
                                                                                                                            </td>
                                                                                                                        </tr>
                                                                                                                    <?php } ?>
                                                                                                                    </tbody>
                                                                                                                </table>
                                                                                                            </div>

                                                                                                        </div>

                                                                                                        <div class="widget-control-actions">
                                                                                                            <div class="alignright">
                                                                                                                <button type="button"
                                                                                                                        class="button-link button-link-delete widget-control-remove js-twer-remove-widget"><?php echo esc_html__( 'Remove',
                                                                                                                    'treweler' ); ?></button>
                                                                                                            </div>
                                                                                                            <br class="clear">
                                                                                                        </div>

                                                                                                    </div>

                                                                                                    <div class="widget-description"></div>
                                                                                                </div>
                                                                                            <?php }
                                                                                          }
                                                                                          ?>

                                                                                        </div>
                                                                                    </div>
                                                                                </div>
                                                                                <div class="widget-control-actions">
                                                                                    <div class="alignleft">
                                                                                        <button class="button button-primary button-large js-twer-add-widget"><?php echo esc_html__( 'Add new',
                                                                                            'treweler' ); ?></button>
                                                                                    </div>
                                                                                    <br class="clear">
                                                                                </div>
                                                                            <?php } ?>
                                                                          </div>

                                                                          <div class="widget-description"></div>
                                                                      </div>
                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>


                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            <!-- Pitch & Bearing Widget -->
                            <div class="tab-pane fade" id="twer-nav-camera" role="tabpanel"
                                 aria-labelledby="twer-nav-camera-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_camera as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'number-v2' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                      </div>
                                                  <?php } elseif ( 'multirange' === $field['type'] ) { ?>
                                                      <div class="multirange-wrapper">
                                                        <?php
                                                        $name = $field['fields'][0]['name'] ?? '';
                                                        $num_value = $field['fields'][0]['value']['current'] ?? '';
                                                        $num_min = $field['fields'][0]['value']['min'] ?? '';
                                                        $num_max = $field['fields'][0]['value']['max'] ?? '';
                                                        $num_step = $field['fields'][0]['value']['step'] ?? '';

                                                        $name_right = $field['fields'][1]['name'] ?? '';
                                                        $num_right_value = $field['fields'][1]['value']['current'] ?? '';
                                                        $num_right_min = $field['fields'][1]['value']['min'] ?? '';
                                                        $num_right_max = $field['fields'][1]['value']['max'] ?? '';
                                                        $num_right_step = $field['fields'][1]['value']['step'] ?? '';
                                                        ?>
                                                          <p class="multirange">
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     name="<?php echo esc_attr( $name ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="large-text lower-slider"/>
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     name="<?php echo esc_attr( $name_right ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="large-text upper-slider"/>
                                                          </p>
                                                          <p class="range-ctrl-label">
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="alighleft"/>
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="alignright"/>
                                                          </p>
                                                      </div>
                                                  <?php } elseif ( 'range' === $field['type'] ) {

                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>


                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>

                                    </table>
                                </div>
                            </div>
                            <!-- End twer-nav-camera -->

                            <div class="tab-pane fade" id="twer-nav-restrict-panning" role="tabpanel" aria-labelledby="twer-nav-restrict-panning-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>

                                        <?php foreach (
                                          $fields_restrict_panning

                                          as $field
                                        ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                  <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                      <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                  </th>
                                                <td>
                                                  <?php

                                                  if ( 'group' === $field['type'] ) { ?>
                                                      <div class="twer-group-elements">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $field_group ) {

                                                              $element_id_group = trim( str_replace( '_', '-',
                                                                $field['name'] . '_' . $field_group['name'] ),
                                                                '-' );
                                                              $field_group['name'] = $field['name'] . '[' . $field_group['name'] . ']';

                                                              $field_class = [];
                                                              if ( isset( $field_group['postfix'] ) ) {
                                                                $field_class[] = 'twer-form-group--append';
                                                              }

                                                              $field_group_placeholder = '';
                                                              if ( isset( $field_group['placeholder'] ) ) {
                                                                $field_group_placeholder = $field_group['placeholder'];
                                                              }

                                                              ?>
                                                                <div class="<?php echo 'colorpicker' === $field_group['type'] ? 'col-simple' : 'col-fixed col-fixed--200' ?>">
                                                                  <?php if ( ! empty( $field_group['label'] ) ) { ?>
                                                                      <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                  <?php } ?>
                                                                  <?php


                                                                  if ( 'text' === $field_group['type'] || 'url' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--text <?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                                          <input type="<?php echo esc_attr( $field_group['type'] ); ?>"
                                                                                 id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="large-text"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                                 placeholder="<?php echo esc_attr( $field_group_placeholder ); ?>"
                                                                          >
                                                                        <?php if ( isset( $field_group['postfix'] ) ) { ?>
                                                                            <div class="twer-form-group-append">
                                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field_group['postfix'] ); ?></span>
                                                                            </div>
                                                                        <?php } ?>
                                                                      </div>


                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>


                            <!-- Preloader -->
                            <div class="tab-pane fade" id="twer-nav-preloader" role="tabpanel"
                                 aria-labelledby="twer-nav-preloader-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>
                                        <?php foreach ( $fields_preloader as $field ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'number-v2' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                      </div>
                                                  <?php } elseif ( 'multirange' === $field['type'] ) { ?>
                                                      <div class="multirange-wrapper">
                                                        <?php
                                                        $name = $field['fields'][0]['name'] ?? '';
                                                        $num_value = $field['fields'][0]['value']['current'] ?? '';
                                                        $num_min = $field['fields'][0]['value']['min'] ?? '';
                                                        $num_max = $field['fields'][0]['value']['max'] ?? '';
                                                        $num_step = $field['fields'][0]['value']['step'] ?? '';

                                                        $name_right = $field['fields'][1]['name'] ?? '';
                                                        $num_right_value = $field['fields'][1]['value']['current'] ?? '';
                                                        $num_right_min = $field['fields'][1]['value']['min'] ?? '';
                                                        $num_right_max = $field['fields'][1]['value']['max'] ?? '';
                                                        $num_right_step = $field['fields'][1]['value']['step'] ?? '';
                                                        ?>
                                                          <p class="multirange">
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     name="<?php echo esc_attr( $name ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="large-text lower-slider"/>
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     name="<?php echo esc_attr( $name_right ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="large-text upper-slider"/>
                                                          </p>
                                                          <p class="range-ctrl-label">
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="alighleft"/>
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="alignright"/>
                                                          </p>
                                                      </div>
                                                  <?php } elseif ( 'range' === $field['type'] ) {

                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                          <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                              <input type="button" class="text-color-picker-btn"
                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                       'treweler' ); ?>">
                                                          </div>
                                                          <!-- .color-picker-text-descr -->
                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                               acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                               acp-show-rgb="no"
                                                               acp-show-hsl="no"
                                                               acp-palette-editable>
                                                          </div>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 class="input-color"
                                                                 value="<?php echo esc_attr( $field['value'] ) ?>">
                                                      </div>


                                                  <?php } elseif ( 'textcolorpicker' === $field['type'] ) { ?>
                                                      <div class="textcolorpicker text-color-picker-left">
                                                          <input type="text"
                                                                 name="<?php echo esc_attr( $field['fields'][0]['name'] ) ?>"
                                                                 id="map_description" class="large-text"
                                                                 value="<?php echo esc_attr( htmlspecialchars( $field['fields'][0]['value'] ) ) ?>">
                                                      </div>
                                                      <div class="textcolorpicker text-color-picker-right">

                                                          <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                              <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['fields'][1]['value'] ) ?>;"></span>
                                                                  <input type="button" class="text-color-picker-btn"
                                                                         value="<?php echo esc_attr__( 'Select Color',
                                                                           'treweler' ); ?>">
                                                              </div>
                                                              <!-- .color-picker-text-descr -->
                                                              <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                                   acp-color="<?php echo esc_attr( $field['fields'][1]['value'] ) ?>"
                                                                   acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                   default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                   acp-show-rgb="no"
                                                                   acp-show-hsl="no"
                                                                   acp-palette-editable>
                                                              </div>
                                                              <input type="hidden"
                                                                     name="<?php echo esc_attr( $field['fields'][1]['name'] ); ?>"
                                                                     class="input-color"
                                                                     value="<?php echo esc_attr( $field['fields'][1]['value'] ) ?>">
                                                          </div>

                                                      </div>
                                                  <?php } elseif ( 'image' === $field['type'] ) { ?>
                                                      <div class="twer-attach js-twer-attach-wrap">


                                                        <?php


                                                        if ( is_numeric( $field['value'] ) ) {
                                                          $attachment = wp_get_attachment_image_src( $field['value'], 'full' );
                                                          $attachment = isset( $attachment[0] ) ? $attachment[0] : $field['value'];
                                                        } else {
                                                          $attachment = $field['value'];
                                                        }

                                                        ?>

                                                          <div class="twer-attach__thumb js-twer-attach-thumb">
                                                            <?php if ( ! empty( $attachment ) ) { ?>
                                                                <img src="<?php echo esc_url( $attachment ); ?>" alt="">
                                                            <?php } ?>
                                                              <button type="button"
                                                                      id="<?php echo esc_attr( $element_id ); ?>"
                                                                      style="<?php echo ! empty( $attachment ) ? 'display:none;' : 'display:block'; ?>"
                                                                      class="twer-attach__add-media js-twer-attach-add">
                                                                <?php echo esc_html__( 'Select Image',
                                                                  'treweler' ); ?>
                                                              </button>

                                                              <input type="hidden"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                     value="<?php echo esc_attr( $field['value'] ) ?>">
                                                          </div>

                                                          <div class="twer-attach__actions js-twer-attach-actions"
                                                               style="<?php echo ! empty( $attachment ) ? 'display:block;' : 'display:none'; ?>">
                                                              <button type="button"
                                                                      class="button js-twer-attach-remove"><?php echo esc_html__( 'Remove',
                                                                  'treweler' ); ?></button>
                                                              <button type="button"
                                                                      class="button js-twer-attach-add"><?php echo esc_html__( 'Change image',
                                                                  'treweler' ); ?></button>
                                                          </div>
                                                      </div>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>

                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <!-- End of Preloader -->


                            <!-- Tour -->
                            <div class="tab-pane fade" id="twer-nav-tour" role="tabpanel"
                                 aria-labelledby="twer-nav-tour-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>

                                        <?php foreach (
                                          $fields_tour

                                          as $field
                                        ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'group' === $field['type'] ) { ?>
                                                      <div class="twer-group-elements">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $field_group ) {

                                                              $element_id_group = trim( str_replace( '_', '-',
                                                                $field['name'] . '_' . $field_group['name'] ),
                                                                '-' );
                                                              $field_group['name'] = $field['name'] . '[' . $field_group['name'] . ']';

                                                              $field_class = [];
                                                              if ( isset( $field_group['postfix'] ) ) {
                                                                $field_class[] = 'twer-form-group--append';
                                                              }

                                                              $field_group_placeholder = '';
                                                              if ( isset( $field_group['placeholder'] ) ) {
                                                                $field_group_placeholder = $field_group['placeholder'];
                                                              }

                                                              ?>
                                                                <div class="<?php echo 'colorpicker' === $field_group['type'] ? 'col-simple' : 'col-fixed col-fixed--130' ?>">
                                                                    <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                  <?php if ( 'text' === $field_group['type'] || 'url' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--text <?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                                          <input type="<?php echo esc_attr( $field_group['type'] ); ?>"
                                                                                 id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="large-text"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                                 placeholder="<?php echo esc_attr( $field_group_placeholder ); ?>"
                                                                          >
                                                                        <?php if ( isset( $field_group['postfix'] ) ) { ?>
                                                                            <div class="twer-form-group-append">
                                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field_group['postfix'] ); ?></span>
                                                                            </div>
                                                                        <?php } ?>
                                                                      </div>


                                                                  <?php } elseif ( 'select' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--select">
                                                                          <select name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                  class="large-select"
                                                                                  id="<?php echo esc_attr( $element_id_group ); ?>">
                                                                            <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                                            <?php } ?>
                                                                          </select>
                                                                      </div>


                                                                  <?php } elseif ( 'colorpicker' === $field_group['type'] ) { ?>
                                                                      <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                                          <div class="map-text-color js-twer-color-picker">
                                                                                    <span class="color-holder"
                                                                                          style="background-color:<?php echo esc_attr( $field_group['value'] ) ?>;"></span>
                                                                              <input type="button"
                                                                                     class="text-color-picker-btn"
                                                                                     value="<?php echo esc_attr__( 'Select Color',
                                                                                       'treweler' ); ?>">
                                                                          </div>
                                                                          <!-- .color-picker-text-descr -->
                                                                          <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                                               acp-color="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                               acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                               default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                               acp-show-rgb="no"
                                                                               acp-show-hsl="no"
                                                                               acp-palette-editable>
                                                                          </div>
                                                                          <input type="hidden"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="input-color"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>">
                                                                      </div>
                                                                  <?php } elseif ( 'checkbox' === $field_group['type'] ) { ?>
                                                                      <input type="hidden"
                                                                             name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                             value="">
                                                                    <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                          <label for="<?php echo esc_attr( $element_id_group ) ?>"
                                                                                 class="twer-switcher">
                                                                              <input type="checkbox"
                                                                                     name="<?php echo esc_attr( $field_group['name'] ); ?>[]"
                                                                                     id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                                              <div class="twer-switcher__slider"></div>
                                                                          </label>
                                                                    <?php } ?>
                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>
                                                  <?php } elseif ( 'number' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'number-v2' === $field['type'] ) {
                                                    $num_value = $field['value']['current'] ?? '';
                                                    $num_min = $field['value']['min'] ?? '';
                                                    $num_max = $field['value']['max'] ?? '';
                                                    $num_step = $field['value']['step'] ?? '';
                                                    ?>
                                                      <div class="twer-form-group twer-form-group--text">
                                                          <input type="number"
                                                                 placeholder="<?php echo esc_attr( $field['value']['placeholder'] ) ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                 class="large-text" style="width: 90px">
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'multirange' === $field['type'] ) { ?>
                                                      <div class="multirange-wrapper">
                                                        <?php
                                                        $name = $field['fields'][0]['name'] ?? '';
                                                        $num_value = $field['fields'][0]['value']['current'] ?? '';
                                                        $num_min = $field['fields'][0]['value']['min'] ?? '';
                                                        $num_max = $field['fields'][0]['value']['max'] ?? '';
                                                        $num_step = $field['fields'][0]['value']['step'] ?? '';

                                                        $name_right = $field['fields'][1]['name'] ?? '';
                                                        $num_right_value = $field['fields'][1]['value']['current'] ?? '';
                                                        $num_right_min = $field['fields'][1]['value']['min'] ?? '';
                                                        $num_right_max = $field['fields'][1]['value']['max'] ?? '';
                                                        $num_right_step = $field['fields'][1]['value']['step'] ?? '';
                                                        ?>
                                                          <p class="multirange">
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     name="<?php echo esc_attr( $name ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="large-text lower-slider"/>
                                                              <input type="range"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     name="<?php echo esc_attr( $name_right ); ?>"
                                                                     id="range-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="large-text upper-slider"/>
                                                          </p>
                                                          <p class="range-ctrl-label">
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $num_value ); ?>"
                                                                     class="alighleft"/>
                                                              <input type="number"
                                                                     step="<?php echo esc_attr( $num_right_step ); ?>"
                                                                     min="<?php echo esc_attr( $num_right_min ); ?>"
                                                                     max="<?php echo esc_attr( $num_right_max ); ?>"
                                                                     id="num-<?php echo esc_attr( $element_id ); ?>-right"
                                                                     value="<?php echo esc_attr( $num_right_value ); ?>"
                                                                     class="alignright"/>
                                                          </p>
                                                      </div>
                                                  <?php } elseif ( 'range' === $field['type'] ) {

                                                    $range_value = isset( $field['value']['current'] ) ? $field['value']['current'] : '';
                                                    $range_min = isset( $field['value']['min'] ) ? $field['value']['min'] : '';
                                                    $range_max = isset( $field['value']['max'] ) ? $field['value']['max'] : '';
                                                    $range_step = isset( $field['value']['step'] ) ? $field['value']['step'] : '';
                                                    ?>
                                                      <div class="twer-range js-twer-range">
                                                          <input type="range"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>-range"
                                                                 class="large-text js-zoom-range" data-id="range"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                          <input type="number"
                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 data-id="range-input"
                                                                 class="large-text js-zoom-range-input"
                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php }
                                                  elseif ( 'group-tour-text' === $field['type'] ) {
                                                  ?>
                                                    <div class="twer-group-elements">
                                                        <div class="row">
                                                          <?php foreach ( $field['value'] as $field_group ):
                                                          $element_id_group = trim( str_replace( '_', '-',
                                                            $field['name'] . '_' . $field_group['name'] ),
                                                            '-' );
                                                          if ( 'text' === $field_group['type'] ): ?>
                                                            <div class="col-fixed" style="min-width: 300px;">
                                                                <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                <div class="twer-form-group twer-form-group--text">
                                                                    <input type="<?php echo esc_attr( $field_group['type'] ); ?>"
                                                                           id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                           name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                           class="large-text"
                                                                           value="<?php echo esc_attr( $field_group['value'] ) ?>">
                                                                </div>
                                                              <?php elseif ( 'checkbox' === $field_group['type'] ): ?>
                                                                <div class="col-fixed" style="min-width: 150px;">
                                                                    <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                    <input type="hidden"
                                                                           name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                           value="">
                                                                  <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                      <label for="<?php echo esc_attr( $element_id_group ) ?>"
                                                                             class="twer-switcher">
                                                                          <input type="checkbox"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>[]"
                                                                                 id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                 value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                                          <div class="twer-switcher__slider"></div>
                                                                      </label>
                                                                  <?php } ?>
                                                                  <?php endif; ?>
                                                                </div>
                                                              <?php endforeach; ?>
                                                            </div>
                                                        </div>
                                                      <?php } elseif ( 'colorpicker' === $field['type'] ) { ?>
                                                          <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                              <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['value'] ) ?>;"></span>
                                                                  <input type="button" class="text-color-picker-btn"
                                                                         value="<?php echo esc_attr__( 'Select Color',
                                                                           'treweler' ); ?>">
                                                              </div>
                                                              <!-- .color-picker-text-descr -->
                                                              <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                                   acp-color="<?php echo esc_attr( $field['value'] ) ?>"
                                                                   acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                   default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                   acp-show-rgb="no"
                                                                   acp-show-hsl="no"
                                                                   acp-palette-editable>
                                                              </div>
                                                              <input type="hidden"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                     class="input-color"
                                                                     value="<?php echo esc_attr( $field['value'] ) ?>">
                                                          </div>


                                                      <?php } elseif ( 'textcolorpicker' === $field['type'] ) { ?>
                                                          <div class="textcolorpicker text-color-picker-left">
                                                              <input type="text"
                                                                     name="<?php echo esc_attr( $field['fields'][0]['name'] ) ?>"
                                                                     id="map_description" class="large-text"
                                                                     value="<?php echo esc_attr( htmlspecialchars( $field['fields'][0]['value'] ) ) ?>">
                                                          </div>
                                                          <div class="textcolorpicker text-color-picker-right">

                                                              <div class="js-twer-color-picker-wrap twer-color-picker-wrap">
                                                                  <div class="map-text-color js-twer-color-picker">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field['fields'][1]['value'] ) ?>;"></span>
                                                                      <input type="button"
                                                                             class="text-color-picker-btn"
                                                                             value="<?php echo esc_attr__( 'Select Color',
                                                                               'treweler' ); ?>">
                                                                  </div>
                                                                  <!-- .color-picker-text-descr -->
                                                                  <div class="js-twer-color-picker-palette twer-color-picker-palette"
                                                                       acp-color="<?php echo esc_attr( $field['fields'][1]['value'] ) ?>"
                                                                       acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                       default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                       acp-show-rgb="no"
                                                                       acp-show-hsl="no"
                                                                       acp-palette-editable>
                                                                  </div>
                                                                  <input type="hidden"
                                                                         name="<?php echo esc_attr( $field['fields'][1]['name'] ); ?>"
                                                                         class="input-color"
                                                                         value="<?php echo esc_attr( $field['fields'][1]['value'] ) ?>">
                                                              </div>

                                                          </div>
                                                      <?php } elseif ( 'text' === $field['type'] ) { ?>
                                                          <div class="twer-text-fields" style="max-width: 350px;">
                                                              <input type="text"
                                                                     name="<?php echo esc_attr( $field['name'] ) ?>"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     class="large-text"
                                                                     value="<?php echo esc_attr( htmlspecialchars( $field['value'] ) ) ?>">
                                                            <?php if ( ! empty( $field['help'] ) ) { ?>
                                                                <a href="#" class="twer-help-tooltip"
                                                                   data-toggle="tooltip"
                                                                   title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                            class="dashicons dashicons-editor-help"></span></a>
                                                            <?php } ?>
                                                          </div>
                                                      <?php } elseif ( 'tour_markers' === $field['type'] ) {
                                                        // tour_marker_repeater
                                                        $tfix = $prefix;
                                                        $id_repeater = trim( str_replace( '_',
                                                          '-',
                                                          "{$field['name']}-{$element['name']}" ),
                                                          '-' );

                                                        $prefix = '_treweler_';
                                                        ?>
                                                          <input type="hidden"
                                                                 name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                 value="">
                                                          <div id="parent-widget-marker-container"
                                                               class="widget-marker-container js-twer-widgets">
                                                              <div class="twer-widget-content">
                                                                  <template
                                                                          class="twer-repeater-template js-twer-repeater-template">
                                                                      <div class="widget js-twer-widget-marker marker-items"
                                                                           data-group="test">
                                                                          <div class="widget-top js-twer-widget-marker-handle js-twer-widget-marker-ui-handle ui-sortable-handle">
                                                                              <div class="widget-title-action">
                                                                                  <button type="button"
                                                                                          class="widget-action hide-if-no-js"
                                                                                          aria-expanded="false">
                                                                                    <span class="toggle-indicator"
                                                                                          aria-hidden="true"></span>
                                                                                  </button>
                                                                              </div>
                                                                              <div class="widget-title">
                                                                                  <h3>
                                                                                      <span class="js-twer-title-widget">%title%</span>
                                                                                      <input type="hidden"
                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_id]' ); ?>"
                                                                                             value="%idMarker%">
                                                                                      <span class="in-widget-title"></span>
                                                                                  </h3>
                                                                                  <span class="cogs"></span>
                                                                              </div>
                                                                          </div>

                                                                          <div class="widget-inside">
                                                                              <div class="widget-content">
                                                                                  <div class="table-responsive">
                                                                                      <table class="table twer-table twer-table--cells-2">
                                                                                          <tbody>
                                                                                          <tr>
                                                                                              <th>
                                                                                                  Advanced settings
                                                                                              </th>
                                                                                              <td>
                                                                                                  <input type="hidden"
                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_advanced_settings]' ); ?>"
                                                                                                         value="">

                                                                                                  <label for="<?php echo esc_attr( $tfix . 'tour_advanced_settings-%index%-main' ) ?>"
                                                                                                         class="twer-switcher">
                                                                                                      <input type="checkbox"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_advanced_settings]' ); ?>[]"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_advanced_settings-%index%-main' ); ?>"
                                                                                                             value="tour_advanced_settings"
                                                                                                             class="js-adv-checkbox">
                                                                                                      <div class="twer-switcher__slider"></div>
                                                                                                  </label>

                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings">
                                                                                              <th>Marker Zoom Level
                                                                                              </th>
                                                                                              <td>
                                                                                                <?php
                                                                                                $range_value = '15';
                                                                                                $range_min = '0';
                                                                                                $range_max = '24';
                                                                                                $range_step = '0.01';
                                                                                                ?>
                                                                                                  <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                      <input type="range"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'marker_zoom_level-%index%-range' ); ?>-range"
                                                                                                             class="large-text js-zoom-range"
                                                                                                             data-id="range"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                      <input type="number"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_zoom]' ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'marker_zoom_level-%index%-main' ); ?>"
                                                                                                             data-id="range-input"
                                                                                                             class="large-text js-zoom-range-input"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                    <?php if ( ! empty( $field['help'] ) ) { ?>
                                                                                                        <a href="#"
                                                                                                           class="twer-help-tooltip"
                                                                                                           data-toggle="tooltip"
                                                                                                           title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                                                                    class="dashicons dashicons-editor-help"></span></a>
                                                                                                    <?php } ?>
                                                                                                  </div>

                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings adv-fly adv-speed">
                                                                                              <th>Speed</th>
                                                                                              <td>
                                                                                                <?php
                                                                                                $num_value = '1,2';
                                                                                                $num_min = '0';
                                                                                                $num_max = '24';
                                                                                                $num_step = '0.01';
                                                                                                ?>
                                                                                                  <div class="twer-form-group twer-form-group--text">
                                                                                                      <input type="number"
                                                                                                             placeholder="<?php echo esc_attr( $num_value ) ?>"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_fly_speed]' ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_fly_speed-%index%-main' ); ?>"
                                                                                                             value=""
                                                                                                             step="<?php echo esc_attr( $num_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $num_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $num_max ); ?>"
                                                                                                             class="large-text"
                                                                                                             style="width: 90px">

                                                                                                      <a href="#"
                                                                                                         class="twer-help-tooltip"
                                                                                                         data-toggle="tooltip"
                                                                                                         title="<?php echo esc_attr( 'The average speed of the animation defined in relation to the Curve.' ); ?>"><span
                                                                                                                  class="dashicons dashicons-editor-help"></span></a>

                                                                                                  </div>
                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings adv-fly adv-curve">
                                                                                              <th>Curve</th>
                                                                                              <td>
                                                                                                <?php
                                                                                                $num_value = '1,42';
                                                                                                $num_min = '0';
                                                                                                $num_max = '24';
                                                                                                $num_step = '0.01';
                                                                                                ?>
                                                                                                  <div class="twer-form-group twer-form-group--text">
                                                                                                      <input type="number"
                                                                                                             placeholder="<?php echo esc_attr( $num_value ) ?>"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_fly_curve]' ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_fly_curve-%index%-main' ); ?>"
                                                                                                             value=""
                                                                                                             step="<?php echo esc_attr( $num_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $num_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $num_max ); ?>"
                                                                                                             class="large-text"
                                                                                                             style="width: 90px">
                                                                                                      <a href="#"
                                                                                                         class="twer-help-tooltip"
                                                                                                         data-toggle="tooltip"
                                                                                                         title="<?php echo esc_attr( 'The zooming "curve" that will occur along the flight path.' ); ?>"><span
                                                                                                                  class="dashicons dashicons-editor-help"></span></a>
                                                                                                  </div>
                                                                                              </td>
                                                                                          </tr>

                                                                                          <tr class="adv-settings">
                                                                                              <th>
                                                                                                  Show marker popup
                                                                                              </th>
                                                                                              <td>

                                                                                                  <input type="hidden"
                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_popup]' ); ?>"
                                                                                                         value="">

                                                                                                  <label for="<?php echo esc_attr( $tfix . 'tour_marker_popup-%index%-main' ) ?>"
                                                                                                         class="twer-switcher">
                                                                                                      <input type="checkbox"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_popup]' ); ?>[]"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_marker_popup-%index%-main' ); ?>"
                                                                                                             value="tour_marker_popup">
                                                                                                      <div class="twer-switcher__slider"></div>
                                                                                                  </label>


                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings">
                                                                                              <th>Bearing</th>
                                                                                              <td>
                                                                                                <?php
                                                                                                $range_value = '0.00';
                                                                                                $range_min = '-360';
                                                                                                $range_max = '360';
                                                                                                $range_step = '0.01';
                                                                                                ?>
                                                                                                  <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                      <input type="range"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_marker_bearing-%index%-range' ); ?>-range"
                                                                                                             class="large-text js-zoom-range"
                                                                                                             data-id="range"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                      <input type="number"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_bearing]' ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_marker_bearing-%index%-main' ); ?>"
                                                                                                             data-id="range-input"
                                                                                                             class="large-text js-zoom-range-input"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                      <a href="#"
                                                                                                         class="twer-help-tooltip"
                                                                                                         data-toggle="tooltip"
                                                                                                         title="<?php echo esc_attr( "The map's angle of rotation, measured in degrees counter-clockwise from north." ); ?>">
                                                                                                          <span class="dashicons dashicons-editor-help"></span>
                                                                                                      </a>
                                                                                                  </div>

                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings">
                                                                                              <th>Pitch</th>
                                                                                              <td>
                                                                                                <?php
                                                                                                $range_value = '0.00';
                                                                                                $range_min = '0';
                                                                                                $range_max = '85';
                                                                                                $range_step = '0.01';
                                                                                                ?>
                                                                                                  <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                      <input type="range"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_marker_pitch-%index%-range' ); ?>-range"
                                                                                                             class="large-text js-zoom-range"
                                                                                                             data-id="range"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                      <input type="number"
                                                                                                             step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                             min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                             max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_marker_pitch]' ); ?>"
                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_marker_pitch-%index%-main' ); ?>"
                                                                                                             data-id="range-input"
                                                                                                             class="large-text js-zoom-range-input"
                                                                                                             value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                      <a href="#"
                                                                                                         class="twer-help-tooltip"
                                                                                                         data-toggle="tooltip"
                                                                                                         title="<?php echo esc_attr( "The map's angle towards the horizon measured in degrees." ); ?>">
                                                                                                          <span class="dashicons dashicons-editor-help"></span>
                                                                                                      </a>
                                                                                                  </div>


                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr class="adv-settings">
                                                                                              <th>Marker Offset</th>
                                                                                              <td>


                                                                                                  <div class="twer-group-elements">
                                                                                                      <div class="row">
                                                                                                          <div class="col-fixed col-fixed--130">
                                                                                                              <label for="treweler-tour-offset-top">Top</label>
                                                                                                              <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                  <input type="text"

                                                                                                                         id="<?php echo esc_attr( $tfix . 'tour_offset_top-%index%-main' ); ?>"
                                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_offset][top]' ); ?>"
                                                                                                                         class="large-text" value="" placeholder="0">
                                                                                                                  <div class="twer-form-group-append">
                                                                                                                      <span class="twer-form-group-append__text">px</span>
                                                                                                                  </div>
                                                                                                              </div>


                                                                                                          </div>
                                                                                                          <div class="col-fixed col-fixed--130">
                                                                                                              <label for="treweler-tour-offset-bottom">Bottom</label>
                                                                                                              <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                  <input type="text"

                                                                                                                         id="<?php echo esc_attr( $tfix . 'tour_offset_bottom-%index%-main' ); ?>"
                                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_offset][bottom]' ); ?>"
                                                                                                                         class="large-text" value="" placeholder="0">
                                                                                                                  <div class="twer-form-group-append">
                                                                                                                      <span class="twer-form-group-append__text">px</span>
                                                                                                                  </div>
                                                                                                              </div>


                                                                                                          </div>
                                                                                                          <div class="col-fixed col-fixed--130">
                                                                                                              <label for="treweler-tour-offset-left">Left</label>
                                                                                                              <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                  <input type="text"
                                                                                                                         id="<?php echo esc_attr( $tfix . 'tour_offset_left-%index%-main' ); ?>"
                                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_offset][left]' ); ?>"
                                                                                                                         class="large-text" value="" placeholder="0">
                                                                                                                  <div class="twer-form-group-append">
                                                                                                                      <span class="twer-form-group-append__text">px</span>
                                                                                                                  </div>
                                                                                                              </div>


                                                                                                          </div>
                                                                                                          <div class="col-fixed col-fixed--130">
                                                                                                              <label for="treweler-tour-offset-right">Right</label>
                                                                                                              <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                  <input type="text"
                                                                                                                         id="<?php echo esc_attr( $tfix . 'tour_offset_right-%index%-main' ); ?>"
                                                                                                                         name="<?php echo esc_attr( $field['name'] . '[main][%index%][tour_offset][right]' ); ?>"
                                                                                                                         class="large-text" value="" placeholder="0">
                                                                                                                  <div class="twer-form-group-append">
                                                                                                                      <span class="twer-form-group-append__text">px</span>
                                                                                                                  </div>
                                                                                                              </div>


                                                                                                          </div>
                                                                                                      </div>
                                                                                                  </div>
                                                                                              </td>
                                                                                          </tr>
                                                                                          <tr>
                                                                                              <th></th>
                                                                                              <td>
                                                                                                  <button type="button"
                                                                                                          class="button-link-delete widget-control-remove js-twer-remove-widget remove-btn">
                                                                                                    <?php echo esc_html__( 'Remove Marker',
                                                                                                      'treweler' ); ?>
                                                                                                  </button>
                                                                                              </td>
                                                                                          </tr>
                                                                                          </tbody>
                                                                                      </table>
                                                                                  </div>
                                                                              </div>
                                                                          </div>
                                                                      </div>
                                                                  </template>

                                                                  <div data-position="<?php echo esc_attr( 'treweler-widgets-tour-list' ) ?>"
                                                                       id="treweler-widgets-tour-list"
                                                                       class="twer-widget-tour-list js-twer-repeater js-twer-ui-repeater ui-sortable">
                                                                    <?php

                                                                    $args = [
                                                                      // basics
                                                                      'post_type'      => 'marker',
                                                                      'post_status'    => 'publish',
                                                                      'posts_per_page' => '-1',
                                                                      // meta query
                                                                      'meta_query'     => [
                                                                        'relation' => 'OR',
                                                                        [
                                                                          'key'     => $prefix . 'marker_map_id',
                                                                          'value'   => $post_id,
                                                                          'compare' => '='
                                                                        ],
                                                                        [
                                                                          'key'     => $prefix . 'marker_map_id',
                                                                          'value'   => serialize( strval( $post_id ) ),
                                                                          'compare' => 'LIKE'
                                                                        ]
                                                                      ]
                                                                    ];

                                                                    $markers = [];
                                                                    $getMarkers = new WP_Query( $args );
                                                                    if ( $getMarkers->post_count > 0 ) {
                                                                      $c = 0;
                                                                      foreach ( $getMarkers->posts as $k => $v ) {
                                                                        $markers[] = $v->ID;
                                                                      }
                                                                    }

                                                                    $tours_values = ! empty( $meta_data->tour_marker_repeater['main'] ) ? array_values( $meta_data->tour_marker_repeater['main'] ) : [];

                                                                    if ( $tours_values ) {
                                                                      $tour_index = 0;
                                                                      foreach ( $tours_values as $tourIndex => $tour_val ) {

                                                                        // skip loop if category not exist
                                                                        if (
                                                                          ! isset( $tour_val['tour_marker_id'] ) ||
                                                                          $tour_val['tour_marker_id'] <= 0 ||
                                                                          'publish' !== get_post_status( $tour_val['tour_marker_id'] ) ||
                                                                          ! in_array( $tour_val['tour_marker_id'],
                                                                            $markers )
                                                                        ) {
                                                                          continue;
                                                                        }

                                                                        if ( isset( $tour_val['tour_marker_id'] ) && $tour_val['tour_marker_id'] != 0 && 'publish' === get_post_status( $tour_val['tour_marker_id'] ) ) {
                                                                          $widget_head = get_the_title( $tour_val['tour_marker_id'] );
                                                                        } else {
                                                                          $widget_head = '&nbsp;';
                                                                        }

                                                                        $checked_tour = (bool) ( isset( $tour_val['tour_advanced_settings'][0] ) ?? $tour_val['tour_advanced_settings'][0] );
                                                                        $checked_fly = ( $meta_data->tour_type === 'fly' );
                                                                        ?>
                                                                          <div class="widget js-twer-widget-marker marker-items"
                                                                               data-group="test">
                                                                              <div class="widget-top js-twer-widget-marker-handle js-twer-widget-marker-ui-handle ui-sortable-handle">
                                                                                  <div class="widget-title-action">
                                                                                      <button type="button"
                                                                                              class="widget-action hide-if-no-js"
                                                                                              aria-expanded="false">
                                                                                    <span class="toggle-indicator"
                                                                                          aria-hidden="true"></span>
                                                                                      </button>
                                                                                  </div>
                                                                                  <div class="widget-title">
                                                                                      <h3>
                                                                                          <span class="js-twer-title-widget"><?php echo esc_html( $widget_head ?? '&nbsp;' ); ?></span>
                                                                                          <input type="hidden"
                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_id]' ); ?>"
                                                                                                 value="<?php echo $tour_val['tour_marker_id']; ?>">
                                                                                          <span class="in-widget-title"></span>
                                                                                      </h3>
                                                                                      <span class="cogs"
                                                                                            style="display: <?php echo $checked_tour ? 'block' : 'none'; ?>;"></span>
                                                                                  </div>
                                                                              </div>

                                                                              <div class="widget-inside">
                                                                                  <div class="widget-content">
                                                                                      <div class="table-responsive">
                                                                                          <table class="table twer-table twer-table--cells-2">
                                                                                              <tbody>

                                                                                              <tr>
                                                                                                  <th>
                                                                                                      Advanced
                                                                                                      settings
                                                                                                  </th>
                                                                                                  <td>
                                                                                                      <input type="hidden"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_advanced_settings]' ); ?>"
                                                                                                             value="">
                                                                                                      <label for="<?php echo esc_attr( 'tour_advanced_settings-' . $tour_index . '-main' ) ?>"
                                                                                                             class="twer-switcher">
                                                                                                          <input type="checkbox"
                                                                                                                 class="js-adv-checkbox"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_advanced_settings]' ); ?>[]"
                                                                                                                 id="<?php echo esc_attr( 'tour_advanced_settings-' . $tour_index . '-main' ) ?>"
                                                                                                                 value="tour_advanced_settings" <?php checked( $checked_tour ); ?>>
                                                                                                          <div class="twer-switcher__slider"></div>
                                                                                                      </label>


                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings"
                                                                                                  style="display: <?php echo $checked_tour ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Marker Zoom
                                                                                                      Level
                                                                                                  </th>
                                                                                                  <td>
                                                                                                    <?php
                                                                                                    $range_value = $tour_val['tour_marker_zoom'];
                                                                                                    $range_min = '0';
                                                                                                    $range_max = '24';
                                                                                                    $range_step = '0.01';
                                                                                                    ?>
                                                                                                      <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                          <input type="range"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_zoom-' . $tour_index . '-range' ); ?>"
                                                                                                                 class="large-text js-zoom-range"
                                                                                                                 data-id="range"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                          <input type="number"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_zoom]' ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_zoom-' . $tour_index . '-main' ); ?>"
                                                                                                                 data-id="range-input"
                                                                                                                 class="large-text js-zoom-range-input"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                                                                            <a href="#"
                                                                                                               class="twer-help-tooltip"
                                                                                                               data-toggle="tooltip"
                                                                                                               title="<?php echo esc_attr( $field['help'] ); ?>">
                                                                                                                <span class="dashicons dashicons-editor-help"></span>
                                                                                                            </a>
                                                                                                        <?php } ?>

                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings adv-fly adv-speed"
                                                                                                  style="display: <?php echo ( $checked_fly && $checked_tour ) ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Speed</th>
                                                                                                  <td>
                                                                                                    <?php
                                                                                                    $num_value = $tour_val['tour_fly_speed'] ?? '';
                                                                                                    $num_min = '0';
                                                                                                    $num_max = '24';
                                                                                                    $num_step = '0.01';
                                                                                                    ?>
                                                                                                      <div class="twer-form-group twer-form-group--text">
                                                                                                          <input type="number"
                                                                                                                 placeholder="<?php echo esc_attr( '1,2' ) ?>"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_fly_speed]' ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_fly_speed-' . $tour_index . '-main' ); ?>"
                                                                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                                                                 class="large-text"
                                                                                                                 style="width: 90px">

                                                                                                          <a href="#"
                                                                                                             class="twer-help-tooltip"
                                                                                                             data-toggle="tooltip"
                                                                                                             title="<?php echo esc_attr( 'The average speed of the animation defined in relation to the Curve.' ); ?>"><span
                                                                                                                      class="dashicons dashicons-editor-help"></span></a>

                                                                                                      </div>
                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings adv-fly adv-curve"
                                                                                                  style="display: <?php echo ( $checked_fly && $checked_tour ) ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Curve</th>
                                                                                                  <td>
                                                                                                    <?php
                                                                                                    $num_value = $tour_val['tour_fly_curve'] ?? '';
                                                                                                    $num_min = '0';
                                                                                                    $num_max = '24';
                                                                                                    $num_step = '0.01';
                                                                                                    ?>
                                                                                                      <div class="twer-form-group twer-form-group--text">
                                                                                                          <input type="number"
                                                                                                                 placeholder="<?php echo esc_attr( '1,42' ) ?>"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_fly_curve]' ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_fly_curve-' . $tour_index . '-main' ); ?>"
                                                                                                                 value="<?php echo esc_attr( $num_value ) ?>"
                                                                                                                 step="<?php echo esc_attr( $num_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $num_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $num_max ); ?>"
                                                                                                                 class="large-text"
                                                                                                                 style="width: 90px">
                                                                                                          <a href="#"
                                                                                                             class="twer-help-tooltip"
                                                                                                             data-toggle="tooltip"
                                                                                                             title="<?php echo esc_attr( 'The zooming "curve" that will occur along the flight path.' ); ?>"><span
                                                                                                                      class="dashicons dashicons-editor-help"></span></a>
                                                                                                      </div>
                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings"
                                                                                                  style="display: <?php echo $checked_tour ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Show marker
                                                                                                      popup
                                                                                                  </th>
                                                                                                  <td>
                                                                                                      <input type="hidden"
                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_popup]' ); ?>"
                                                                                                             value="">
                                                                                                    <?php
                                                                                                    $checked = in_array( 'tour_marker_popup',
                                                                                                      isset( $meta_data->tour_marker_repeater['main'][ $tour_index ]['tour_marker_popup'] ) ? (array) $meta_data->tour_marker_repeater['main'][ $tour_index ]['tour_marker_popup'] : [] );
                                                                                                    ?>
                                                                                                      <label for="<?php echo esc_attr( 'tour_marker_popup-' . $tour_index . '-main' ) ?>"
                                                                                                             class="twer-switcher">
                                                                                                          <input type="checkbox"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_popup]' ); ?>[]"
                                                                                                                 id="<?php echo esc_attr( 'tour_marker_popup-' . $tour_index . '-main' ) ?>"
                                                                                                                 value="tour_marker_popup" <?php checked( $checked ); ?>>
                                                                                                          <div class="twer-switcher__slider"></div>
                                                                                                      </label>


                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings"
                                                                                                  style="display: <?php echo $checked_tour ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Bearing</th>
                                                                                                  <td>
                                                                                                    <?php
                                                                                                    $range_value = $tour_val['tour_marker_bearing'];
                                                                                                    $range_min = '-360';
                                                                                                    $range_max = '360';
                                                                                                    $range_step = '0.01';
                                                                                                    ?>
                                                                                                      <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                          <input type="range"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_bearing-' . $tour_index ); ?>-range"
                                                                                                                 class="large-text js-zoom-range"
                                                                                                                 data-id="range"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                          <input type="number"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_bearing]' ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_bearing-' . $tour_index . '-main' ); ?>"
                                                                                                                 data-id="range-input"
                                                                                                                 class="large-text js-zoom-range-input"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                          <a href="#"
                                                                                                             class="twer-help-tooltip"
                                                                                                             data-toggle="tooltip"
                                                                                                             title="<?php echo esc_attr( "The map's angle of rotation, measured in degrees counter-clockwise from north." ); ?>">
                                                                                                              <span class="dashicons dashicons-editor-help"></span>
                                                                                                          </a>
                                                                                                      </div>

                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings"
                                                                                                  style="display: <?php echo $checked_tour ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Pitch</th>
                                                                                                  <td>
                                                                                                    <?php
                                                                                                    $range_value = $tour_val['tour_marker_pitch'];
                                                                                                    $range_min = '0';
                                                                                                    $range_max = '85';
                                                                                                    $range_step = '0.01';
                                                                                                    ?>
                                                                                                      <div class="twer-range js-twer-range js-twer-tour-range">
                                                                                                          <input type="range"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_pitch-' . $tour_index ); ?>-range"
                                                                                                                 class="large-text js-zoom-range"
                                                                                                                 data-id="range"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>
                                                                                                          <input type="number"
                                                                                                                 step="<?php echo esc_attr( $range_step ); ?>"
                                                                                                                 min="<?php echo esc_attr( $range_min ); ?>"
                                                                                                                 max="<?php echo esc_attr( $range_max ); ?>"
                                                                                                                 name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_marker_pitch]' ); ?>"
                                                                                                                 id="<?php echo esc_attr( $tfix . 'tour_marker_pitch-' . $tour_index . '-main' ); ?>"
                                                                                                                 data-id="range-input"
                                                                                                                 class="large-text js-zoom-range-input"
                                                                                                                 value="<?php echo esc_attr( $range_value ); ?>"/>

                                                                                                          <a href="#"
                                                                                                             class="twer-help-tooltip"
                                                                                                             data-toggle="tooltip"
                                                                                                             title="<?php echo esc_attr( "The map's angle towards the horizon measured in degrees." ); ?>">
                                                                                                              <span class="dashicons dashicons-editor-help"></span>
                                                                                                          </a>

                                                                                                      </div>


                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr class="adv-settings"
                                                                                                  style="display: <?php echo $checked_tour ? 'table-row' : 'none'; ?>;">
                                                                                                  <th>Marker Offset</th>
                                                                                                  <td>
                                                                                                      <div class="twer-group-elements">
                                                                                                          <div class="row">
                                                                                                              <div class="col-fixed col-fixed--130">
                                                                                                                <?php

                                                                                                                $tour_offset_top = isset( $tour_val['tour_offset']['top'] ) ? $tour_val['tour_offset']['top'] : '';
                                                                                                                ?>
                                                                                                                  <label for="treweler-tour-offset-top">Top</label>
                                                                                                                  <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                      <input type="text"


                                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_offset][top]' ); ?>"
                                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_offset_top-' . $tour_index . '-main' ); ?>"
                                                                                                                             value="<?php echo esc_attr( $tour_offset_top ) ?>"

                                                                                                                             class="large-text" placeholder="0">
                                                                                                                      <div class="twer-form-group-append">
                                                                                                                          <span class="twer-form-group-append__text">px</span>
                                                                                                                      </div>
                                                                                                                  </div>


                                                                                                              </div>
                                                                                                              <div class="col-fixed col-fixed--130">
                                                                                                                  <label for="treweler-tour-offset-bottom">Bottom</label>
                                                                                                                  <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                    <?php

                                                                                                                    $tour_offset_bottom = isset( $tour_val['tour_offset']['bottom'] ) ? $tour_val['tour_offset']['bottom'] : '';
                                                                                                                    ?>
                                                                                                                      <input type="text"

                                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_offset][bottom]' ); ?>"
                                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_offset_bottom-' . $tour_index . '-main' ); ?>"
                                                                                                                             value="<?php echo esc_attr( $tour_offset_bottom ) ?>"

                                                                                                                             class="large-text" placeholder="0">
                                                                                                                      <div class="twer-form-group-append">
                                                                                                                          <span class="twer-form-group-append__text">px</span>
                                                                                                                      </div>
                                                                                                                  </div>


                                                                                                              </div>
                                                                                                              <div class="col-fixed col-fixed--130">
                                                                                                                  <label for="treweler-tour-offset-left">Left</label>
                                                                                                                  <div class="twer-form-group twer-form-group--text twer-form-group--append">
                                                                                                                    <?php

                                                                                                                    $tour_offset_left = isset( $tour_val['tour_offset']['left'] ) ? $tour_val['tour_offset']['left'] : '';
                                                                                                                    ?>
                                                                                                                      <input type="text"

                                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_offset][left]' ); ?>"
                                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_offset_left-' . $tour_index . '-main' ); ?>"
                                                                                                                             value="<?php echo esc_attr( $tour_offset_left ) ?>"

                                                                                                                             class="large-text" placeholder="0">
                                                                                                                      <div class="twer-form-group-append">
                                                                                                                          <span class="twer-form-group-append__text">px</span>
                                                                                                                      </div>
                                                                                                                  </div>


                                                                                                              </div>
                                                                                                              <div class="col-fixed col-fixed--130">
                                                                                                                  <label for="treweler-tour-offset-right">Right</label>
                                                                                                                  <div class="twer-form-group twer-form-group--text twer-form-group--append">

                                                                                                                    <?php

                                                                                                                    $tour_offset_right = isset( $tour_val['tour_offset']['right'] ) ? $tour_val['tour_offset']['right'] : '';

                                                                                                                    ?>

                                                                                                                      <input type="text"

                                                                                                                             name="<?php echo esc_attr( $field['name'] . '[main][' . $tour_index . '][tour_offset][right]' ); ?>"
                                                                                                                             id="<?php echo esc_attr( $tfix . 'tour_offset_right-' . $tour_index . '-main' ); ?>"
                                                                                                                             value="<?php echo esc_attr( $tour_offset_right ) ?>"

                                                                                                                             class="large-text" placeholder="0">
                                                                                                                      <div class="twer-form-group-append">
                                                                                                                          <span class="twer-form-group-append__text">px</span>
                                                                                                                      </div>
                                                                                                                  </div>


                                                                                                              </div>
                                                                                                          </div>
                                                                                                      </div>
                                                                                                  </td>
                                                                                              </tr>
                                                                                              <tr>
                                                                                                  <th></th>
                                                                                                  <td>
                                                                                                      <button type="button"
                                                                                                              class="button-link-delete widget-control-remove js-twer-remove-widget remove-btn">
                                                                                                        <?php echo esc_html__( 'Remove Marker',
                                                                                                          'treweler' ); ?>
                                                                                                      </button>
                                                                                                  </td>
                                                                                              </tr>
                                                                                              </tbody>
                                                                                          </table>
                                                                                      </div>
                                                                                  </div>
                                                                              </div>
                                                                          </div>
                                                                        <?php
                                                                        $tour_index ++;
                                                                      }
                                                                    }
                                                                    ?>
                                                                  </div>
                                                              </div>


                                                              <div class="twer-widget-secondary-btn-add">
                                                                <?php

                                                                if ( ! empty( $markers ) ) {
                                                                  wp_dropdown_cpt( array(
                                                                    'show_option_all'   => esc_html__( "Select a Marker", 'treweler' ),
                                                                    'option_none_value' => esc_html__( "Select a Marker", 'treweler' ),
                                                                    'name_filter'       => 'tour_marker_picker',
                                                                    'id'                => 'tour-marker-picker',
                                                                    'orderby'           => 'date',
                                                                    'class'             => 'tour-marker-picker',
                                                                    'order'             => 'DESC',
                                                                    'include'           => $markers,
                                                                    'exclude'           => array(),
                                                                    'post_type'         => 'marker',
                                                                    'post_status'       => 'publish',
                                                                    'numberposts'       => - 1,
                                                                    'suppress_filters'  => false,
                                                                  ) );
                                                                } else {
                                                                  ?>
                                                                    <select name="tour_marker_picker"
                                                                            class="tour-marker-picker"
                                                                            id="tour-marker-picker">
                                                                        <option value="0"
                                                                                selected="selected"> <?php echo esc_html__( 'Marker not found',
                                                                            'treweler' ) ?> </option>
                                                                    </select>
                                                                  <?php
                                                                }

                                                                ?>
                                                                  <button type="button" id="add-widget-marker"
                                                                          class="button button-primary button-large js-twer-add-widget-marker">
                                                                      Add Marker
                                                                  </button>
                                                              </div>
                                                          </div>

                                                      <?php } elseif ( 'image' === $field['type'] ) { ?>
                                                          <div class="twer-attach js-twer-attach-wrap">

                                                            <?php

                                                            if ( is_numeric( $field['value'] ) ) {
                                                              $attachment = wp_get_attachment_image_src( $field['value'], 'full' );
                                                              $attachment = isset( $attachment[0] ) ? $attachment[0] : $field['value'];
                                                            } else {
                                                              $attachment = $field['value'];
                                                            }
                                                            ?>

                                                              <div class="twer-attach__thumb js-twer-attach-thumb">
                                                                <?php if ( ! empty( $attachment ) ) { ?>
                                                                    <img src="<?php echo esc_url( $attachment ); ?>"
                                                                         alt="">
                                                                <?php } ?>
                                                                  <button type="button"
                                                                          id="<?php echo esc_attr( $element_id ); ?>"
                                                                          style="<?php echo ! empty( $attachment ) ? 'display:none;' : 'display:block'; ?>"
                                                                          class="twer-attach__add-media js-twer-attach-add">
                                                                    <?php echo esc_html__( 'Select Image',
                                                                      'treweler' ); ?>
                                                                  </button>

                                                                  <input type="hidden"
                                                                         name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                         value="<?php echo esc_attr( $field['value'] ) ?>">
                                                              </div>

                                                              <div class="twer-attach__actions js-twer-attach-actions"
                                                                   style="<?php echo ! empty( $attachment ) ? 'display:block;' : 'display:none'; ?>">
                                                                  <button type="button"
                                                                          class="button js-twer-attach-remove"><?php echo esc_html__( 'Remove',
                                                                      'treweler' ); ?></button>
                                                                  <button type="button"
                                                                          class="button js-twer-attach-add"><?php echo esc_html__( 'Change image',
                                                                      'treweler' ); ?></button>
                                                              </div>
                                                          </div>
                                                      <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>

                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <!-- End of Tour -->


                            <!-- Store-locator -->
                            <div class="tab-pane fade" id="twer-nav-store-locator" role="tabpanel"
                                 aria-labelledby="twer-nav-store-locator-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>

                                        <?php foreach (
                                          $fields_store_locator

                                          as $field
                                        ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                                <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                    <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                </th>
                                                <td>
                                                  <?php if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'group' === $field['type'] ) { ?>
                                                      <div class="twer-group-elements">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $field_group ) {

                                                              $element_id_group = trim( str_replace( '_', '-',
                                                                $field['name'] . '_' . $field_group['name'] ),
                                                                '-' );
                                                              $field_group['name'] = $field['name'] . '[' . $field_group['name'] . ']';

                                                              $field_class = [];
                                                              if ( isset( $field_group['postfix'] ) ) {
                                                                $field_class[] = 'twer-form-group--append';
                                                              }

                                                              $group_class = isset( $field_group['class'] ) ? $field_group['class'] : 'col-fixed';
                                                              ?>
                                                                <div class="<?php echo 'colorpicker' === $field_group['type'] ? 'col-simple' : $group_class ?>">
                                                                  <?php if ( ! empty( $field_group['label'] ) ) { ?>
                                                                      <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                  <?php } ?>
                                                                  <?php if ( 'select' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--select">
                                                                          <select name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                  class="large-select"
                                                                                  id="<?php echo esc_attr( $element_id_group ); ?>">
                                                                            <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                                            <?php } ?>
                                                                          </select>
                                                                      </div>


                                                                  <?php } elseif ( 'multiple-select' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group">
                                                                          <input type="hidden" name="<?php echo esc_attr( $field_group['name'] ); ?>" value="">
                                                                          <select multiple="multiple" name="<?php echo esc_attr( $field_group['name'] ); ?>[]"
                                                                                  class="large-select"
                                                                                  id="<?php echo esc_attr( $element_id_group ); ?>">
                                                                            <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                                            <?php } ?>
                                                                          </select>
                                                                      </div>
                                                                    <?php
                                                                  } elseif ( 'checkbox' === $field_group['type'] ) { ?>
                                                                      <input type="hidden"
                                                                             name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                             value="">
                                                                    <?php foreach ( $field_group['value'] as $data ) { ?>
                                                                          <label for="<?php echo esc_attr( $element_id_group ) ?>"
                                                                                 class="twer-switcher">
                                                                              <input type="checkbox"
                                                                                     name="<?php echo esc_attr( $field_group['name'] ); ?>[]"
                                                                                     id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                                              <div class="twer-switcher__slider"></div>
                                                                          </label>
                                                                    <?php } ?>
                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>

                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <!-- End of Store-locator -->


                            <!-- Boundaries -->
                            <div class="tab-pane fade" id="twer-nav-boundaries" role="tabpanel"
                                 aria-labelledby="twer-nav-boundaries-tab">
                                <div class="table-responsive">
                                    <table class="table twer-table twer-table--cells-2">
                                        <tbody>

                                        <?php foreach (
                                          $fields_boundaries

                                          as $field
                                        ) {
                                          $element_id = trim( str_replace( '_', '-', $field['name'] ), '-' );
                                          ?>
                                            <tr class="section-<?php echo esc_attr( $element_id ); ?>">
                                              <?php if ( 'table' !== $field['type'] ) { ?>
                                                  <th class="th-<?php echo esc_attr( $element_id ); ?>">
                                                      <label for="<?php echo esc_attr( $element_id ) ?>"><?php echo esc_html( $field['label'] ); ?></label>
                                                  </th>
                                              <?php } ?>
                                                <td <?php echo 'table' === $field['type']  ? 'colspan="2"' : ''; ?>>
                                                  <?php
                                                  if ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) { ?>
                                                                <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'group' === $field['type'] ) { ?>
                                                      <div class="twer-group-elements">
                                                          <div class="row">
                                                            <?php foreach ( $field['value'] as $field_group ) {

                                                              $element_id_group = trim( str_replace( '_', '-',
                                                                $field['name'] . '_' . $field_group['name'] ),
                                                                '-' );
                                                              $field_group['name'] = $field['name'] . '[' . $field_group['name'] . ']';

                                                              $field_class = [];
                                                              if ( isset( $field_group['postfix'] ) ) {
                                                                $field_class[] = 'twer-form-group--append';
                                                              }

                                                              $field_group_placeholder = '';
                                                              if ( isset( $field_group['placeholder'] ) ) {
                                                                $field_group_placeholder = $field_group['placeholder'];
                                                              }

                                                              ?>
                                                                <div class="<?php echo 'colorpicker' === $field_group['type'] ? 'col-simple' : 'col-fixed col-fixed--200' ?>">
                                                                  <?php if ( ! empty( $field_group['label'] ) ) { ?>
                                                                      <label for="<?php echo esc_attr( $element_id_group ); ?>"><?php echo esc_attr( $field_group['label'] ); ?></label>
                                                                  <?php } ?>
                                                                  <?php


                                                                  if ( 'text' === $field_group['type'] || 'url' === $field_group['type'] ) { ?>
                                                                      <div class="twer-form-group twer-form-group--text <?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                                          <input type="<?php echo esc_attr( $field_group['type'] ); ?>"
                                                                                 id="<?php echo esc_attr( $element_id_group ); ?>"
                                                                                 name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                 class="large-text"
                                                                                 value="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                                 placeholder="<?php echo esc_attr( $field_group_placeholder ); ?>"
                                                                          >
                                                                        <?php if ( isset( $field_group['postfix'] ) ) { ?>
                                                                            <div class="twer-form-group-append">
                                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field_group['postfix'] ); ?></span>
                                                                            </div>
                                                                        <?php } ?>
                                                                      </div>


                                                                  <?php } elseif ( 'colorpicker' === $field_group['type'] ) { ?>


                                                                      <div class="clearfix">
                                                                          <div id="<?php echo esc_attr( $element_id_group ); ?>" class="js-twer-color-picker-wrap-o twer-color-picker-wrap" style="float: left;">
                                                                              <div class="map-text-color js-twer-color-picker-o">
                                                                <span class="color-holder"
                                                                      style="background-color:<?php echo esc_attr( $field_group['value'] ) ?>;"></span>
                                                                                  <input type="button" style="margin: 0;" class="text-color-picker-btn"
                                                                                         value="<?php echo esc_attr__( 'Select Color',
                                                                                           'treweler' ); ?>">
                                                                              </div>
                                                                              <!-- .color-picker-text-descr -->
                                                                              <div style="position: absolute; left: 0;   bottom: 33px;" class="js-twer-color-picker-palette-o twer-color-picker-palette"
                                                                                   acp-color="<?php echo esc_attr( $field_group['value'] ) ?>"
                                                                                   acp-palette="<?php echo esc_attr( $defaultColors . $custom_color ); ?>"
                                                                                   default-palette="<?php echo esc_attr( $defaultColors ); ?>"
                                                                                   acp-show-rgb="no"
                                                                                   acp-show-hsl="no"
                                                                                   acp-palette-editable>
                                                                              </div>
                                                                              <input type="hidden"
                                                                                     name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                     class="input-color"
                                                                                     value="<?php echo esc_attr( $field_group['value'] ) ?>">

                                                                              <input type="hidden" class="js-twer-colorpicker-custom-color" name="default_color" value="<?php echo esc_attr( $custom_color ); ?>">


                                                                          </div>
                                                                      </div>
                                                                  <?php } elseif ( 'select' === $field_group['type'] ) {

                                                                    $field_group_id = isset( $field_group['id'] ) ? $field_group['id'] : $element_id;
                                                                    $fields_atts = isset($field_group['atts']) ? $field_group['atts'] : '';
                                                                    ?>
                                                                      <div class="twer-form-group twer-form-group--select">
                                                                          <select <?php echo $fields_atts; ?> name="<?php echo esc_attr( $field_group['name'] ); ?>"
                                                                                  class="large-select"
                                                                                  id="<?php echo esc_attr( $field_group_id ); ?>">


                                                                            <?php if(!empty($field_group['value'])) { foreach ( $field_group['value'] as $data ) {

                                                                              $is_group = isset( $data['is_group'] ) ? $data['is_group'] : false;

                                                                              if ( ! $is_group ) {
                                                                                ?>
                                                                                  <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                                              <?php } else { ?>
                                                                                  <optgroup label="<?php echo esc_attr( $data['label'] ); ?>">
                                                                                    <?php

                                                                                    if ( ! empty( $data['value'] ) ) {
                                                                                      foreach ( $data['value'] as $group_value ) {
                                                                                        ?>
                                                                                          <option value="<?php echo esc_attr( $group_value['value'] ) ?>" <?php selected( $group_value['selected'] ); ?>><?php echo esc_html( $group_value['label'] ); ?></option>
                                                                                        <?php
                                                                                      }
                                                                                    }

                                                                                    ?>
                                                                                  </optgroup>
                                                                              <?php } ?>
                                                                            <?php } } ?>



                                                                          </select>
                                                                      </div>
                                                                  <?php } ?>
                                                                </div>
                                                            <?php } ?>
                                                          </div>
                                                      </div>
                                                  <?php  } elseif ( 'table' === $field['type'] ) { ?>
                                                        <div class="twer-regions" style="margin: 0 -15px;">
                                                            <div class="container-fluid">
                                                                <div class="table-responsive">
                                                                <table id="js-twer-regions-datatable" class="table twer-table twer-table-mini table-hover" width="100%">
                                                                    <thead>
                                                                    <tr>
                                                                        <th class="no-sort th-all" >
                                                                            <label for="twer-active-all-regions" class="twer-switcher">
                                                                                <input type="checkbox" class="js-twer-active-all-regions" id="twer-active-all-regions" value="active-all-regions">
                                                                                <span class="twer-switcher__slider"></span>
                                                                            </label>
                                                                        </th>
                                                                        <th class="th-name w-25"><?php echo esc_html__( 'Name', 'treweler' ) ?></th>
                                                                        <th class="w-25"><?php echo esc_html__( 'Region', 'treweler' ) ?></th>
                                                                        <th class="no-sort th-color"><?php echo esc_html__( 'Custom Color', 'treweler' ); ?></th>
                                                                        <th class="th-val no-sort"><?php echo esc_html__( 'Value', 'treweler' ) ?></th>
                                                                        <th class="no-sort th-all">
                                                                          <?php echo esc_html__( 'Hide', 'treweler' ); ?>&nbsp;
                                                                            <label for="twer-hide-all-regions" class="twer-switcher">
                                                                                <input type="checkbox" class="js-twer-hide-all-regions" id="twer-hide-all-regions" value="hide-all-regions">
                                                                                <span class="twer-switcher__slider"></span>
                                                                            </label>
                                                                        </th>
                                                                    </tr>
                                                                    </thead>
                                                                    <tbody></tbody>
                                                                </table>
                                                            </div>
                                                            </div>
                                                        </div>
                                                  <?php } elseif ( 'select' === $field['type'] ) { ?>
                                                      <div class="twer-form-group twer-form-group--select">
                                                          <select name="<?php echo esc_attr( $field['name'] ); ?>"
                                                                  class="large-select"
                                                                  id="<?php echo esc_attr( $element_id ); ?>">
                                                            <?php foreach ( $field['value'] as $data ) {

                                                              $is_group = isset( $data['is_group'] ) ? $data['is_group'] : false;

                                                              if ( ! $is_group ) {
                                                                ?>
                                                                  <option value="<?php echo esc_attr( $data['value'] ) ?>" <?php selected( $data['selected'] ); ?>><?php echo esc_html( $data['label'] ); ?></option>
                                                              <?php } else { ?>
                                                                  <optgroup label="<?php echo esc_attr( $data['label'] ); ?>">
                                                                    <?php

                                                                    if ( ! empty( $data['value'] ) ) {
                                                                      foreach ( $data['value'] as $group_value ) {
                                                                        ?>
                                                                          <option value="<?php echo esc_attr( $group_value['value'] ) ?>" <?php selected( $group_value['selected'] ); ?>><?php echo esc_html( $group_value['label'] ); ?></option>
                                                                        <?php
                                                                      }
                                                                    }

                                                                    ?>
                                                                  </optgroup>
                                                              <?php } ?>
                                                            <?php } ?>
                                                          </select>
                                                      </div>
                                                  <?php } elseif ( 'text' === $field['type'] ) {

                                                    $field_class = [ 'twer-form-group twer-form-group--text' ];
                                                    $field_placeholder = '';
                                                    if ( isset( $field['size'] ) ) {
                                                      $field_class[] = 'twer-form-group--' . $field['size'];
                                                    }

                                                    if ( isset( $field['placeholder'] ) ) {
                                                      $field_placeholder = $field['placeholder'];
                                                    }
                                                    if ( isset( $field['postfix'] ) ) {
                                                      $field_class[] = 'twer-form-group--append';
                                                    }

                                                    ?>
                                                      <div class="<?php echo esc_attr( implode( ' ', $field_class ) ); ?>">
                                                          <input type="text"
                                                                 name="<?php echo esc_attr( $field['name'] ) ?>"
                                                                 id="<?php echo esc_attr( $element_id ); ?>"
                                                                 class="large-text"
                                                                 value="<?php echo esc_attr( htmlspecialchars( $field['value'] ) ) ?>"
                                                                 placeholder="<?php echo esc_attr( $field_placeholder ); ?>"
                                                          >
                                                        <?php if ( isset( $field['postfix'] ) ) { ?>
                                                            <div class="twer-form-group-append">
                                                                <span class="twer-form-group-append__text"><?php echo esc_html( $field['postfix'] ); ?></span>
                                                            </div>
                                                        <?php } ?>
                                                        <?php if ( ! empty( $field['help'] ) ) { ?>
                                                            <a href="#" class="twer-help-tooltip"
                                                               data-toggle="tooltip"
                                                               title="<?php echo esc_attr( $field['help'] ); ?>"><span
                                                                        class="dashicons dashicons-editor-help"></span></a>
                                                        <?php } ?>
                                                      </div>
                                                  <?php } elseif ( 'checkbox' === $field['type'] ) { ?>
                                                      <input type="hidden"
                                                             name="<?php echo esc_attr( $field['name'] ); ?>"
                                                             value="">
                                                    <?php foreach ( $field['value'] as $data ) { ?>
                                                          <label for="<?php echo esc_attr( $element_id ) ?>"
                                                                 class="twer-switcher">
                                                              <input type="checkbox"
                                                                     name="<?php echo esc_attr( $field['name'] ); ?>[]"
                                                                     id="<?php echo esc_attr( $element_id ); ?>"
                                                                     value="<?php echo esc_attr( $data['value'] ) ?>" <?php checked( $data['checked'] ); ?>><?php echo esc_html( $data['label'] ); ?>
                                                              <div class="twer-switcher__slider"></div>
                                                          </label>
                                                    <?php } ?>
                                                  <?php } ?>
                                                </td>
                                            </tr>
                                        <?php } ?>

                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <!-- End of Boundaries -->
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
